@@ -20,6 +20,7 @@
 #include <openrct2/OpenRCT2.h>
 #include <openrct2/SpriteIds.h>
 #include <openrct2/audio/Audio.h>
+#include <openrct2/drawing/Rectangle.h>
 #include <openrct2/entity/EntityList.h>
 #include <openrct2/management/Research.h>
 #include <openrct2/scenario/Scenario.h>
@@ -30,6 +31,8 @@
 #include <openrct2/world/Scenery.h>
 #include <string>
 
+using namespace OpenRCT2::Drawing;
+
 namespace OpenRCT2::Ui::Windows
 {
     static constexpr int32_t kToolbarHeight = 32;
@@ -69,25 +72,27 @@ namespace OpenRCT2::Ui::Windows
         };
 
     public:
-        void OnOpen() override
+        void onOpen() override
         {
-            SetWidgets(kEditorBottomToolbarWidgets);
+            setWidgets(kEditorBottomToolbarWidgets);
 
-            InitScrollWidgets();
+            initScrollWidgets();
             SetAllSceneryItemsInvented();
         }
 
         bool GameHasEntities() const
         {
-            return GetNumFreeEntities() != kMaxEntities || getGameState().park.flags & PARK_FLAGS_SPRITES_INITIALISED;
+            auto& gameState = getGameState();
+            return gameState.entities.GetNumFreeEntities() != kMaxEntities
+                || gameState.park.flags & PARK_FLAGS_SPRITES_INITIALISED;
         }
 
-        void OnPrepareDraw() override
+        void onPrepareDraw() override
         {
             ColourSchemeUpdateByClass(
                 this,
-                gLegacyScene == LegacyScene::scenarioEditor ? WindowClass::EditorScenarioBottomToolbar
-                                                            : WindowClass::EditorTrackBottomToolbar);
+                gLegacyScene == LegacyScene::scenarioEditor ? WindowClass::editorScenarioBottomToolbar
+                                                            : WindowClass::editorTrackBottomToolbar);
 
             uint16_t screenWidth = ContextGetWidth();
             widgets[WIDX_NEXT_IMAGE].left = screenWidth - 200;
@@ -120,7 +125,7 @@ namespace OpenRCT2::Ui::Windows
             }
         }
 
-        void OnDraw(RenderTarget& rt) override
+        void onDraw(RenderTarget& rt) override
         {
             auto drawPreviousButton = widgets[WIDX_PREVIOUS_STEP_BUTTON].type != WidgetType::empty;
             auto drawNextButton = widgets[WIDX_NEXT_STEP_BUTTON].type != WidgetType::empty;
@@ -131,7 +136,7 @@ namespace OpenRCT2::Ui::Windows
             if (drawNextButton)
                 DrawRightButtonBack(rt);
 
-            DrawWidgets(rt);
+            drawWidgets(rt);
 
             if (drawPreviousButton)
                 DrawLeftButton(rt);
@@ -142,7 +147,7 @@ namespace OpenRCT2::Ui::Windows
             DrawStepText(rt);
         }
 
-        void OnMouseUp(WidgetIndex widgetIndex) override
+        void onMouseUp(WidgetIndex widgetIndex) override
         {
             auto& gameState = getGameState();
             if (widgetIndex == WIDX_PREVIOUS_STEP_BUTTON)
@@ -173,7 +178,7 @@ namespace OpenRCT2::Ui::Windows
             SetAllSceneryItemsInvented();
             WindowScenerySetDefaultPlacementConfiguration();
             getGameState().editorStep = EditorStep::LandscapeEditor;
-            ContextOpenWindow(WindowClass::Map);
+            ContextOpenWindow(WindowClass::map);
             GfxInvalidateScreen();
         }
 
@@ -182,7 +187,7 @@ namespace OpenRCT2::Ui::Windows
             auto* windowMgr = Ui::GetWindowManager();
             windowMgr->CloseAll();
 
-            ContextOpenWindow(WindowClass::EditorInventionList);
+            ContextOpenWindow(WindowClass::editorInventionList);
             getGameState().editorStep = EditorStep::InventionsListSetUp;
             GfxInvalidateScreen();
         }
@@ -192,7 +197,7 @@ namespace OpenRCT2::Ui::Windows
             auto* windowMgr = Ui::GetWindowManager();
             windowMgr->CloseAll();
 
-            ContextOpenWindow(WindowClass::EditorScenarioOptions);
+            ContextOpenWindow(WindowClass::editorScenarioOptions);
             getGameState().editorStep = EditorStep::ObjectiveSelection;
             GfxInvalidateScreen();
         }
@@ -202,7 +207,7 @@ namespace OpenRCT2::Ui::Windows
             auto* windowMgr = Ui::GetWindowManager();
             windowMgr->CloseAll();
 
-            ContextOpenWindow(WindowClass::EditorScenarioOptions);
+            ContextOpenWindow(WindowClass::editorScenarioOptions);
             getGameState().editorStep = EditorStep::OptionsSelection;
             GfxInvalidateScreen();
         }
@@ -213,17 +218,17 @@ namespace OpenRCT2::Ui::Windows
                 return;
 
             auto* windowMgr = Ui::GetWindowManager();
-            windowMgr->CloseByClass(WindowClass::EditorObjectSelection);
+            windowMgr->CloseByClass(WindowClass::editorObjectSelection);
 
             FinishObjectSelection();
             if (gLegacyScene == LegacyScene::trackDesigner)
             {
-                ContextOpenWindow(WindowClass::ConstructRide);
+                ContextOpenWindow(WindowClass::constructRide);
             }
             else
             {
-                ContextOpenWindow(WindowClass::Map);
-                ContextOpenWindow(WindowClass::Mapgen);
+                ContextOpenWindow(WindowClass::map);
+                ContextOpenWindow(WindowClass::mapgen);
             }
         }
 
@@ -234,7 +239,7 @@ namespace OpenRCT2::Ui::Windows
             {
                 auto* windowMgr = Ui::GetWindowManager();
                 windowMgr->CloseAll();
-                ContextOpenWindow(WindowClass::EditorInventionList);
+                ContextOpenWindow(WindowClass::editorInventionList);
                 getGameState().editorStep = EditorStep::InventionsListSetUp;
             }
             else
@@ -250,7 +255,7 @@ namespace OpenRCT2::Ui::Windows
             auto* windowMgr = Ui::GetWindowManager();
             windowMgr->CloseAll();
 
-            ContextOpenWindow(WindowClass::EditorScenarioOptions);
+            ContextOpenWindow(WindowClass::editorScenarioOptions);
             getGameState().editorStep = EditorStep::ObjectiveSelection;
             GfxInvalidateScreen();
         }
@@ -260,7 +265,7 @@ namespace OpenRCT2::Ui::Windows
             auto* windowMgr = Ui::GetWindowManager();
             windowMgr->CloseAll();
 
-            ContextOpenWindow(WindowClass::EditorScenarioOptions);
+            ContextOpenWindow(WindowClass::editorScenarioOptions);
             getGameState().editorStep = EditorStep::OptionsSelection;
             GfxInvalidateScreen();
         }
@@ -270,7 +275,7 @@ namespace OpenRCT2::Ui::Windows
             auto* windowMgr = Ui::GetWindowManager();
             windowMgr->CloseAll();
 
-            ContextOpenWindow(WindowClass::EditorScenarioOptions);
+            ContextOpenWindow(WindowClass::editorScenarioOptions);
             getGameState().editorStep = EditorStep::ScenarioDetails;
             GfxInvalidateScreen();
         }
@@ -309,7 +314,7 @@ namespace OpenRCT2::Ui::Windows
             auto* windowMgr = Ui::GetWindowManager();
             windowMgr->CloseAll();
 
-            auto intent = Intent(WindowClass::Loadsave);
+            auto intent = Intent(WindowClass::loadsave);
             intent.PutEnumExtra<LoadSaveAction>(INTENT_EXTRA_LOADSAVE_ACTION, LoadSaveAction::save);
             intent.PutEnumExtra<LoadSaveType>(INTENT_EXTRA_LOADSAVE_TYPE, LoadSaveType::scenario);
             intent.PutExtra(INTENT_EXTRA_PATH, gameState.scenarioOptions.name);
@@ -334,7 +339,7 @@ namespace OpenRCT2::Ui::Windows
             const auto& previousWidget = widgets[WIDX_PREVIOUS_IMAGE];
             auto leftTop = windowPos + ScreenCoordsXY{ previousWidget.left, previousWidget.top };
             auto rightBottom = windowPos + ScreenCoordsXY{ previousWidget.right, previousWidget.bottom };
-            GfxFilterRect(rt, { leftTop, rightBottom }, FilterPaletteID::Palette51);
+            Rectangle::filter(rt, { leftTop, rightBottom }, FilterPaletteID::palette51);
         }
 
         void DrawLeftButton(RenderTarget& rt)
@@ -343,15 +348,17 @@ namespace OpenRCT2::Ui::Windows
                 + ScreenCoordsXY{ widgets[WIDX_PREVIOUS_IMAGE].left + 1, widgets[WIDX_PREVIOUS_IMAGE].top + 1 };
             const auto bottomRight = windowPos
                 + ScreenCoordsXY{ widgets[WIDX_PREVIOUS_IMAGE].right - 1, widgets[WIDX_PREVIOUS_IMAGE].bottom - 1 };
-            GfxFillRectInset(rt, { topLeft, bottomRight }, colours[1], INSET_RECT_F_30);
+            Rectangle::fillInset(
+                rt, { topLeft, bottomRight }, colours[1], Rectangle::BorderStyle::inset, Rectangle::FillBrightness::light,
+                Rectangle::FillMode::none);
 
             GfxDrawSprite(
                 rt, ImageId(SPR_PREVIOUS),
                 windowPos + ScreenCoordsXY{ widgets[WIDX_PREVIOUS_IMAGE].left + 6, widgets[WIDX_PREVIOUS_IMAGE].top + 6 });
 
             colour_t textColour = colours[1].colour;
-            if (gHoverWidget.window_classification == WindowClass::BottomToolbar
-                && gHoverWidget.widget_index == WIDX_PREVIOUS_STEP_BUTTON)
+            if (gHoverWidget.windowClassification == WindowClass::bottomToolbar
+                && gHoverWidget.widgetIndex == WIDX_PREVIOUS_STEP_BUTTON)
             {
                 textColour = COLOUR_WHITE;
             }
@@ -372,7 +379,7 @@ namespace OpenRCT2::Ui::Windows
             auto nextWidget = widgets[WIDX_NEXT_IMAGE];
             auto leftTop = windowPos + ScreenCoordsXY{ nextWidget.left, nextWidget.top };
             auto rightBottom = windowPos + ScreenCoordsXY{ nextWidget.right, nextWidget.bottom };
-            GfxFilterRect(rt, { leftTop, rightBottom }, FilterPaletteID::Palette51);
+            Rectangle::filter(rt, { leftTop, rightBottom }, FilterPaletteID::palette51);
         }
 
         void DrawRightButton(RenderTarget& rt)
@@ -381,7 +388,9 @@ namespace OpenRCT2::Ui::Windows
                 + ScreenCoordsXY{ widgets[WIDX_NEXT_IMAGE].left + 1, widgets[WIDX_NEXT_IMAGE].top + 1 };
             const auto bottomRight = windowPos
                 + ScreenCoordsXY{ widgets[WIDX_NEXT_IMAGE].right - 1, widgets[WIDX_NEXT_IMAGE].bottom - 1 };
-            GfxFillRectInset(rt, { topLeft, bottomRight }, colours[1], INSET_RECT_F_30);
+            Rectangle::fillInset(
+                rt, { topLeft, bottomRight }, colours[1], Rectangle::BorderStyle::inset, Rectangle::FillBrightness::light,
+                Rectangle::FillMode::none);
 
             GfxDrawSprite(
                 rt, ImageId(SPR_NEXT),
@@ -389,8 +398,8 @@ namespace OpenRCT2::Ui::Windows
 
             colour_t textColour = colours[1].colour;
 
-            if (gHoverWidget.window_classification == WindowClass::BottomToolbar
-                && gHoverWidget.widget_index == WIDX_NEXT_STEP_BUTTON)
+            if (gHoverWidget.windowClassification == WindowClass::bottomToolbar
+                && gHoverWidget.widgetIndex == WIDX_NEXT_STEP_BUTTON)
             {
                 textColour = COLOUR_WHITE;
             }
@@ -449,8 +458,9 @@ namespace OpenRCT2::Ui::Windows
     {
         auto* windowMgr = GetWindowManager();
         auto* window = windowMgr->Create<EditorBottomToolbarWindow>(
-            WindowClass::BottomToolbar, ScreenCoordsXY(0, ContextGetHeight() - kToolbarHeight),
-            { ContextGetWidth(), kToolbarHeight }, WF_STICK_TO_FRONT | WF_TRANSPARENT | WF_NO_BACKGROUND | WF_NO_TITLE_BAR);
+            WindowClass::bottomToolbar, ScreenCoordsXY(0, ContextGetHeight() - kToolbarHeight),
+            { ContextGetWidth(), kToolbarHeight },
+            { WindowFlag::stickToFront, WindowFlag::transparent, WindowFlag::noBackground, WindowFlag::noTitleBar });
 
         return window;
     }
