@@ -18,6 +18,7 @@
 #include <openrct2/EditorObjectSelectionSession.h>
 #include <openrct2/Game.h>
 #include <openrct2/GameState.h>
+#include <openrct2/Input.h>
 #include <openrct2/OpenRCT2.h>
 #include <openrct2/SpriteIds.h>
 #include <openrct2/actions/LoadOrQuitAction.h>
@@ -26,6 +27,7 @@
 #include <openrct2/core/EnumUtils.hpp>
 #include <openrct2/core/Path.hpp>
 #include <openrct2/core/String.hpp>
+#include <openrct2/drawing/Rectangle.h>
 #include <openrct2/drawing/Text.h>
 #include <openrct2/localisation/Formatter.h>
 #include <openrct2/object/ClimateObject.h>
@@ -45,6 +47,8 @@
 #include <string>
 #include <vector>
 
+using namespace OpenRCT2::Drawing;
+
 namespace OpenRCT2::Ui::Windows
 {
     enum : uint16_t
@@ -215,7 +219,7 @@ namespace OpenRCT2::Ui::Windows
         WIDX_TAB_1,
     };
 
-    validate_global_widx(WC_EDITOR_OBJECT_SELECTION, WIDX_TAB_1);
+    VALIDATE_GLOBAL_WIDX(WC_EDITOR_OBJECT_SELECTION, WIDX_TAB_1);
 
     // clang-format off
     static constexpr auto _window_editor_object_selection_widgets = makeWidgets(
@@ -269,27 +273,27 @@ namespace OpenRCT2::Ui::Windows
          *
          * rct2: 0x006AA64E
          */
-        void OnOpen() override
+        void onOpen() override
         {
-            InitWidgets();
+            initWidgets();
 
             Sub6AB211();
             ResetSelectedObjectCountAndSize();
 
-            _filterFlags = FILTER_RIDES_ALL | Config::Get().interface.ObjectSelectionFilterFlags;
+            _filterFlags = FILTER_RIDES_ALL | Config::Get().interface.objectSelectionFilterFlags;
             _filter.clear();
 
             WindowInitScrollWidgets(*this);
 
-            selected_tab = 0;
-            selected_list_item = -1;
+            selectedTab = 0;
+            selectedListItem = -1;
 
             WindowSetResize(*this, kMinimumWindowSize, kMaximumWindowSize);
 
             _listSortType = RIDE_SORT_TYPE;
             _listSortDescending = false;
 
-            disabled_widgets |= 1u << WIDX_FILTER_RIDE_TAB_FRAME;
+            disabledWidgets |= 1u << WIDX_FILTER_RIDE_TAB_FRAME;
 
             VisibleListRefresh();
         }
@@ -299,7 +303,7 @@ namespace OpenRCT2::Ui::Windows
             _overrideChecks = newState;
         }
 
-        bool CanClose() override
+        bool canClose() override
         {
             // Prevent window closure when selection is invalid
             return _overrideChecks || EditorObjectSelectionWindowCheck();
@@ -309,7 +313,7 @@ namespace OpenRCT2::Ui::Windows
          *
          * rct2: 0x006AB199
          */
-        void OnClose() override
+        void onClose() override
         {
             UnloadUnselectedObjects();
             EditorLoadSelectedObjects();
@@ -340,15 +344,15 @@ namespace OpenRCT2::Ui::Windows
             ContextBroadcastIntent(&intent);
         }
 
-        void OnUpdate() override
+        void onUpdate() override
         {
             if (GetCurrentTextBox().window.classification == classification && GetCurrentTextBox().window.number == number)
             {
                 WindowUpdateTextboxCaret();
-                InvalidateWidget(WIDX_FILTER_TEXT_BOX);
+                invalidateWidget(WIDX_FILTER_TEXT_BOX);
             }
 
-            auto& currentPage = ObjectSelectionPages[selected_tab];
+            auto& currentPage = ObjectSelectionPages[selectedTab];
             if (currentPage.subTabs.empty())
                 return;
 
@@ -357,18 +361,18 @@ namespace OpenRCT2::Ui::Windows
 
             auto& subTabDef = currentPage.subTabs[_selectedSubTab];
 
-            frame_no++;
-            if (frame_no >= subTabDef.animationLength)
-                frame_no = 0;
+            currentFrame++;
+            if (currentFrame >= subTabDef.animationLength)
+                currentFrame = 0;
 
-            InvalidateWidget(WIDX_SUB_TAB_0 + _selectedSubTab);
+            invalidateWidget(WIDX_SUB_TAB_0 + _selectedSubTab);
         }
 
         /**
          *
          * rct2: 0x006AAFAB
          */
-        void OnMouseUp(WidgetIndex widgetIndex) override
+        void onMouseUp(WidgetIndex widgetIndex) override
         {
             switch (widgetIndex)
             {
@@ -378,7 +382,7 @@ namespace OpenRCT2::Ui::Windows
                         return;
 
                     auto* windowMgr = Ui::GetWindowManager();
-                    windowMgr->CloseByClass(WindowClass::EditorObjectSelection);
+                    windowMgr->CloseByClass(WindowClass::editorObjectSelection);
 
                     if (isInEditorMode())
                     {
@@ -405,32 +409,32 @@ namespace OpenRCT2::Ui::Windows
                 {
                     _selectedSubTab = widgetIndex - WIDX_SUB_TAB_0;
 
-                    auto& currentPage = ObjectSelectionPages[selected_tab];
+                    auto& currentPage = ObjectSelectionPages[selectedTab];
                     auto& subTabDef = currentPage.subTabs[_selectedSubTab];
                     _filterFlags &= ~FILTER_RIDES_ALL;
                     _filterFlags |= subTabDef.flagFilter;
 
-                    Config::Get().interface.ObjectSelectionFilterFlags = _filterFlags;
+                    Config::Get().interface.objectSelectionFilterFlags = _filterFlags;
                     Config::Save();
 
                     VisibleListRefresh();
 
-                    selected_list_item = -1;
+                    selectedListItem = -1;
                     scrolls[0].contentOffsetY = 0;
-                    frame_no = 0;
-                    Invalidate();
+                    currentFrame = 0;
+                    invalidate();
                     break;
                 }
 
                 case WIDX_INSTALL_TRACK:
                 {
-                    if (selected_list_item != -1)
+                    if (selectedListItem != -1)
                     {
-                        selected_list_item = -1;
+                        selectedListItem = -1;
                     }
-                    Invalidate();
+                    invalidate();
 
-                    auto intent = Intent(WindowClass::Loadsave);
+                    auto intent = Intent(WindowClass::loadsave);
                     intent.PutEnumExtra<LoadSaveAction>(INTENT_EXTRA_LOADSAVE_ACTION, LoadSaveAction::load);
                     intent.PutEnumExtra<LoadSaveType>(INTENT_EXTRA_LOADSAVE_TYPE, LoadSaveType::track);
                     ContextOpenIntent(&intent);
@@ -443,7 +447,7 @@ namespace OpenRCT2::Ui::Windows
                     _filter.clear();
                     scrolls->contentOffsetY = 0;
                     VisibleListRefresh();
-                    Invalidate();
+                    invalidate();
                     break;
                 case WIDX_LIST_SORT_TYPE:
                     if (_listSortType == RIDE_SORT_TYPE)
@@ -487,13 +491,13 @@ namespace OpenRCT2::Ui::Windows
                     if (widgetIndex >= WIDX_TAB_1
                         && static_cast<size_t>(widgetIndex) < WIDX_TAB_1 + std::size(ObjectSelectionPages))
                     {
-                        SetPage(widgetIndex - WIDX_TAB_1);
+                        setPage(widgetIndex - WIDX_TAB_1);
                     }
                     break;
             }
         }
 
-        void OnResize() override
+        void onResize() override
         {
             WindowSetResize(*this, kMinimumWindowSize, kMaximumWindowSize);
         }
@@ -504,7 +508,7 @@ namespace OpenRCT2::Ui::Windows
             STR_OBJECT_FILTER_OPENRCT2_OFFICIAL, STR_OBJECT_FILTER_CUSTOM,
         };
 
-        void OnMouseDown(WidgetIndex widgetIndex) override
+        void onMouseDown(WidgetIndex widgetIndex) override
         {
             int32_t numSelectionItems = 0;
 
@@ -549,7 +553,7 @@ namespace OpenRCT2::Ui::Windows
             }
         }
 
-        void OnDropdown(WidgetIndex widgetIndex, int32_t dropdownIndex) override
+        void onDropdown(WidgetIndex widgetIndex, int32_t dropdownIndex) override
         {
             if (dropdownIndex == -1)
                 return;
@@ -571,13 +575,13 @@ namespace OpenRCT2::Ui::Windows
                     {
                         _filterFlags ^= (1 << dropdownIndex);
                     }
-                    Config::Get().interface.ObjectSelectionFilterFlags = _filterFlags;
+                    Config::Get().interface.objectSelectionFilterFlags = _filterFlags;
                     Config::Save();
 
                     scrolls->contentOffsetY = 0;
 
                     VisibleListRefresh();
-                    Invalidate();
+                    invalidate();
                     break;
             }
         }
@@ -586,7 +590,7 @@ namespace OpenRCT2::Ui::Windows
          *
          * rct2: 0x006AB031
          */
-        ScreenSize OnScrollGetSize(int32_t scrollIndex) override
+        ScreenSize onScrollGetSize(int32_t scrollIndex) override
         {
             const auto newHeight = static_cast<int32_t>(_listItems.size() * kScrollableRowHeight);
             return { 0, newHeight };
@@ -596,12 +600,12 @@ namespace OpenRCT2::Ui::Windows
          *
          * rct2: 0x006AB0B6
          */
-        void OnScrollMouseDown(int32_t scrollIndex, const ScreenCoordsXY& screenCoords) override
+        void onScrollMouseDown(int32_t scrollIndex, const ScreenCoordsXY& screenCoords) override
         {
             // Used for in-game object selection cheat to prevent crashing the game
             // when windows attempt to draw objects that don't exist any more
             auto* windowMgr = Ui::GetWindowManager();
-            windowMgr->CloseAllExceptClass(WindowClass::EditorObjectSelection);
+            windowMgr->CloseAllExceptClass(WindowClass::editorObjectSelection);
 
             int32_t selected_object = GetObjectFromObjectSelection(GetSelectedObjectType(), screenCoords.y);
             if (selected_object == -1)
@@ -612,10 +616,10 @@ namespace OpenRCT2::Ui::Windows
             if (object_selection_flags & ObjectSelectionFlags::Flag6)
                 return;
 
-            Invalidate();
+            invalidate();
 
             const CursorState* state = ContextGetCursorState();
-            Audio::Play(Audio::SoundId::Click1, 0, state->position.x);
+            Audio::Play(Audio::SoundId::click1, 0, state->position.x);
 
             if (gLegacyScene == LegacyScene::trackDesignsManager)
             {
@@ -635,7 +639,7 @@ namespace OpenRCT2::Ui::Windows
                 auto& objManager = GetContext()->GetObjectManager();
                 objManager.LoadObject(_loadedObject.get()->GetIdentifier());
 
-                windowMgr->ForceClose(WindowClass::EditorObjectSelection);
+                windowMgr->ForceClose(WindowClass::editorObjectSelection);
 
                 // This function calls window_track_list_open
                 ManageTracks();
@@ -661,7 +665,7 @@ namespace OpenRCT2::Ui::Windows
             if (IsFilterActive(FILTER_SELECTED) || IsFilterActive(FILTER_NONSELECTED))
             {
                 VisibleListRefresh();
-                Invalidate();
+                invalidate();
             }
 
             if (_gSceneryGroupPartialSelectError.has_value())
@@ -684,7 +688,7 @@ namespace OpenRCT2::Ui::Windows
          *
          * rct2: 0x006AB079
          */
-        void OnScrollMouseOver(int32_t scrollIndex, const ScreenCoordsXY& screenCoords) override
+        void onScrollMouseOver(int32_t scrollIndex, const ScreenCoordsXY& screenCoords) override
         {
             int32_t selectedObject = GetObjectFromObjectSelection(GetSelectedObjectType(), screenCoords.y);
             if (selectedObject != -1)
@@ -696,9 +700,9 @@ namespace OpenRCT2::Ui::Windows
                     selectedObject = -1;
                 }
             }
-            if (selectedObject != selected_list_item)
+            if (selectedObject != selectedListItem)
             {
-                selected_list_item = selectedObject;
+                selectedListItem = selectedObject;
 
                 if (_loadedObject != nullptr)
                 {
@@ -717,11 +721,11 @@ namespace OpenRCT2::Ui::Windows
                     }
                 }
 
-                Invalidate();
+                invalidate();
             }
         }
 
-        void OnScrollDraw(int32_t scrollIndex, RenderTarget& rt) override
+        void onScrollDraw(int32_t scrollIndex, RenderTarget& rt) override
         {
             // ScrollPaint
             ScreenCoordsXY screenCoords;
@@ -738,16 +742,18 @@ namespace OpenRCT2::Ui::Windows
                 {
                     // Draw checkbox
                     if (!(gLegacyScene == LegacyScene::trackDesignsManager) && !(*listItem.flags & 0x20))
-                        GfxFillRectInset(
-                            rt, { { 2, screenCoords.y }, { 11, screenCoords.y + 10 } }, colours[1], INSET_RECT_F_E0);
+                        Rectangle::fillInset(
+                            rt, { { 2, screenCoords.y }, { 11, screenCoords.y + 10 } }, colours[1],
+                            Rectangle::BorderStyle::inset, Rectangle::FillBrightness::dark,
+                            Rectangle::FillMode::dontLightenWhenInset);
 
                     // Highlight background
-                    auto highlighted = i == static_cast<size_t>(selected_list_item)
+                    auto highlighted = i == static_cast<size_t>(selectedListItem)
                         && !(*listItem.flags & ObjectSelectionFlags::Flag6);
                     if (highlighted)
                     {
                         auto bottom = screenCoords.y + (kScrollableRowHeight - 1);
-                        GfxFilterRect(rt, { 0, screenCoords.y, width, bottom }, FilterPaletteID::PaletteDarken1);
+                        Rectangle::filter(rt, { 0, screenCoords.y, width, bottom }, FilterPaletteID::paletteDarken1);
                     }
 
                     // Draw checkmark
@@ -813,7 +819,7 @@ namespace OpenRCT2::Ui::Windows
          *
          * rct2: 0x006AB058
          */
-        OpenRCT2String OnTooltip(const WidgetIndex widgetIndex, const StringId fallback) override
+        OpenRCT2String onTooltip(const WidgetIndex widgetIndex, const StringId fallback) override
         {
             if (widgetIndex >= WIDX_TAB_1 && static_cast<size_t>(widgetIndex) < WIDX_TAB_1 + std::size(ObjectSelectionPages))
             {
@@ -824,7 +830,7 @@ namespace OpenRCT2::Ui::Windows
             return { fallback, {} };
         }
 
-        void OnTextInput(WidgetIndex widgetIndex, std::string_view text) override
+        void onTextInput(WidgetIndex widgetIndex, std::string_view text) override
         {
             if (widgetIndex != WIDX_FILTER_TEXT_BOX)
                 return;
@@ -837,10 +843,10 @@ namespace OpenRCT2::Ui::Windows
             scrolls->contentOffsetY = 0;
 
             VisibleListRefresh();
-            Invalidate();
+            invalidate();
         }
 
-        void OnPrepareDraw() override
+        void onPrepareDraw() override
         {
             // Resize widgets
             widgets[WIDX_LIST].right = width - 309;
@@ -851,12 +857,12 @@ namespace OpenRCT2::Ui::Windows
             widgets[WIDX_RELOAD_OBJECT].right = width - 9;
 
             auto& dropdownWidget = widgets[WIDX_FILTER_DROPDOWN];
-            ResizeDropdown(WIDX_FILTER_DROPDOWN, { width - kFilterWidth - 10, dropdownWidget.top }, { kFilterWidth, 14 });
+            resizeDropdown(WIDX_FILTER_DROPDOWN, { width - kFilterWidth - 10, dropdownWidget.top }, { kFilterWidth, 14 });
             auto& installTrackWidget = widgets[WIDX_INSTALL_TRACK];
             installTrackWidget.moveToX(dropdownWidget.left - installTrackWidget.width() - 10);
 
             // Set pressed widgets
-            pressed_widgets |= 1uLL << WIDX_PREVIEW;
+            pressedWidgets |= 1uLL << WIDX_PREVIEW;
             SetPressedTab();
 
             // Set window title and buttons
@@ -878,7 +884,7 @@ namespace OpenRCT2::Ui::Windows
             }
 
             // Set title parameters for current page
-            const auto& currentPage = ObjectSelectionPages[selected_tab];
+            const auto& currentPage = ObjectSelectionPages[selectedTab];
             auto ft = Formatter::Common();
             if (!currentPage.subTabs.empty())
                 ft.Add<StringId>(currentPage.subTabs[_selectedSubTab].tooltip);
@@ -888,7 +894,7 @@ namespace OpenRCT2::Ui::Windows
             // Set filter dropdown caption
             if (!IsFilterActive(FILTER_SOURCES_ALL))
             {
-                // Only one source active?
+                // only one source active?
                 uint32_t sources = _filterFlags & FILTER_SOURCES_ALL;
                 auto numSourcesActive = std::popcount(sources);
                 if (numSourcesActive == 1)
@@ -922,7 +928,7 @@ namespace OpenRCT2::Ui::Windows
                     widget.type = WidgetType::empty;
             }
 
-            if (Config::Get().general.DebuggingTools)
+            if (Config::Get().general.debuggingTools)
                 widgets[WIDX_RELOAD_OBJECT].type = WidgetType::imgBtn;
             else
                 widgets[WIDX_RELOAD_OBJECT].type = WidgetType::empty;
@@ -956,13 +962,13 @@ namespace OpenRCT2::Ui::Windows
             {
                 widgets[WIDX_SUB_TAB_0 + i].tooltip = i < numSubTabs ? currentPage.subTabs[i].tooltip : kStringIdNone;
                 widgets[WIDX_SUB_TAB_0 + i].type = i < numSubTabs ? WidgetType::tab : WidgetType::empty;
-                pressed_widgets &= ~(1uLL << (WIDX_SUB_TAB_0 + i));
+                pressedWidgets &= ~(1uLL << (WIDX_SUB_TAB_0 + i));
             }
 
             // Mark current sub-tab as active, and toggle tab frame
             if (hasSubTabs)
             {
-                pressed_widgets |= (1uLL << (WIDX_SUB_TAB_0 + _selectedSubTab));
+                pressedWidgets |= (1uLL << (WIDX_SUB_TAB_0 + _selectedSubTab));
                 widgets[WIDX_FILTER_RIDE_TAB_FRAME].type = WidgetType::imgBtn;
             }
             else
@@ -1002,9 +1008,9 @@ namespace OpenRCT2::Ui::Windows
             widgets[WIDX_PREVIEW].right = widgets[WIDX_PREVIEW].left + kPreviewSize;
         }
 
-        void OnDraw(RenderTarget& rt) override
+        void onDraw(RenderTarget& rt) override
         {
-            DrawWidgets(rt);
+            drawWidgets(rt);
 
             // Draw main tab images
             for (size_t i = 0; i < std::size(ObjectSelectionPages); i++)
@@ -1023,7 +1029,7 @@ namespace OpenRCT2::Ui::Windows
             };
 
             // Draw sub-tab images, if applicable
-            auto& currentPage = ObjectSelectionPages[selected_tab];
+            auto& currentPage = ObjectSelectionPages[selectedTab];
             if (!currentPage.subTabs.empty())
             {
                 for (auto i = 0u; i < currentPage.subTabs.size(); i++)
@@ -1036,7 +1042,7 @@ namespace OpenRCT2::Ui::Windows
                     int32_t frame = 0;
                     if (subTabDef.animationLength > 1 && _selectedSubTab == i)
                     {
-                        frame = frame_no / subTabDef.animationDivisor;
+                        frame = currentFrame / subTabDef.animationDivisor;
                     }
 
                     // TODO: generalise this?
@@ -1056,7 +1062,7 @@ namespace OpenRCT2::Ui::Windows
 
             // Preview background
             const auto& previewWidget = widgets[WIDX_PREVIEW];
-            GfxFillRect(
+            Rectangle::fill(
                 rt,
                 { windowPos + ScreenCoordsXY{ previewWidget.left + 1, previewWidget.top + 1 },
                   windowPos + ScreenCoordsXY{ previewWidget.right - 1, previewWidget.bottom - 1 } },
@@ -1098,7 +1104,7 @@ namespace OpenRCT2::Ui::Windows
                 DrawTextEllipsised(rt, screenPos, listSortRideWidget.width(), STR_OBJECTS_SORT_RIDE, ft, { colours[1] });
             }
 
-            if (selected_list_item == -1 || _loadedObject == nullptr)
+            if (selectedListItem == -1 || _loadedObject == nullptr)
                 return;
 
             // Draw preview
@@ -1123,7 +1129,7 @@ namespace OpenRCT2::Ui::Windows
             {
                 if (ObjectSelectionPages[offset].mainObjectType == objectType)
                 {
-                    SetPage(offset);
+                    setPage(offset);
                     return;
                 }
             }
@@ -1132,9 +1138,9 @@ namespace OpenRCT2::Ui::Windows
     private:
         bool tabWidgetsInitialised = false;
 
-        void InitWidgets()
+        void initWidgets()
         {
-            SetWidgets(_window_editor_object_selection_widgets);
+            setWidgets(_window_editor_object_selection_widgets);
             if (!tabWidgetsInitialised)
             {
                 // Create a new tab widget based on the initial one
@@ -1148,18 +1154,18 @@ namespace OpenRCT2::Ui::Windows
             }
         }
 
-        void SetPage(int32_t _page)
+        void setPage(int32_t _page)
         {
             // Skip setting page if we're already on this page, unless we're initialising the window
-            if (selected_tab == _page && !widgets.empty())
+            if (selectedTab == _page && !widgets.empty())
                 return;
 
-            selected_tab = _page;
+            selectedTab = _page;
             _selectedSubTab = 0;
             _filterFlags |= FILTER_RIDES_ALL;
-            selected_list_item = -1;
+            selectedListItem = -1;
             scrolls[0].contentOffsetY = 0;
-            frame_no = 0;
+            currentFrame = 0;
 
             if (_page == EnumValue(ObjectType::ride))
             {
@@ -1173,7 +1179,7 @@ namespace OpenRCT2::Ui::Windows
             }
 
             VisibleListRefresh();
-            Invalidate();
+            invalidate();
         }
 
         void VisibleListRefresh()
@@ -1181,7 +1187,7 @@ namespace OpenRCT2::Ui::Windows
             int32_t numObjects = static_cast<int32_t>(ObjectRepositoryGetItemsCount());
 
             VisibleListClear();
-            selected_list_item = -1;
+            selectedListItem = -1;
 
             const ObjectRepositoryItem* items = ObjectRepositoryGetItems();
             for (int32_t i = 0; i < numObjects; i++)
@@ -1233,7 +1239,7 @@ namespace OpenRCT2::Ui::Windows
                     }
                 }
             }
-            Invalidate();
+            invalidate();
         }
 
         void VisibleListClear()
@@ -1249,7 +1255,7 @@ namespace OpenRCT2::Ui::Windows
 
             // Draw name of object
             {
-                ObjectListItem* listItem = &_listItems[selected_list_item];
+                ObjectListItem* listItem = &_listItems[selectedListItem];
 
                 auto ft = Formatter();
                 ft.Add<StringId>(STR_STRING);
@@ -1287,12 +1293,12 @@ namespace OpenRCT2::Ui::Windows
             {
                 auto* rideObject = reinterpret_cast<RideObject*>(_loadedObject.get());
                 const auto& rideEntry = rideObject->GetEntry();
-                if (rideEntry.shop_item[0] != ShopItem::None)
+                if (rideEntry.shop_item[0] != ShopItem::none)
                 {
                     std::string sells = "";
                     for (size_t i = 0; i < std::size(rideEntry.shop_item); i++)
                     {
-                        if (rideEntry.shop_item[i] == ShopItem::None)
+                        if (rideEntry.shop_item[i] == ShopItem::none)
                             continue;
 
                         if (!sells.empty())
@@ -1336,15 +1342,15 @@ namespace OpenRCT2::Ui::Windows
         {
             switch (type)
             {
-                case AnimationPeepType::Handyman:
+                case AnimationPeepType::handyman:
                     return STR_HANDYMAN_PLURAL;
-                case AnimationPeepType::Mechanic:
+                case AnimationPeepType::mechanic:
                     return STR_MECHANIC_PLURAL;
-                case AnimationPeepType::Security:
+                case AnimationPeepType::security:
                     return STR_SECURITY_GUARD_PLURAL;
-                case AnimationPeepType::Entertainer:
+                case AnimationPeepType::entertainer:
                     return STR_ENTERTAINER_PLURAL;
-                case AnimationPeepType::Guest:
+                case AnimationPeepType::guest:
                 default:
                     return STR_GUESTS;
             }
@@ -1352,7 +1358,7 @@ namespace OpenRCT2::Ui::Windows
 
         void DrawDebugData(RenderTarget& rt)
         {
-            ObjectListItem* listItem = &_listItems[selected_list_item];
+            ObjectListItem* listItem = &_listItems[selectedListItem];
             auto screenPos = windowPos + ScreenCoordsXY{ width - 5, height - (kListRowHeight * 6) };
 
             // Draw fallback image warning
@@ -1441,7 +1447,7 @@ namespace OpenRCT2::Ui::Windows
 
         bool FilterCompatibilityObject(const ObjectRepositoryItem& item, uint8_t objectFlag)
         {
-            // Only show compat objects if they are selected already.
+            // only show compat objects if they are selected already.
             return !(item.Flags & ObjectItemFlags::IsCompatibilityObject) || (objectFlag & ObjectSelectionFlags::Selected);
         }
 
@@ -1496,21 +1502,21 @@ namespace OpenRCT2::Ui::Windows
         bool SourcesMatch(ObjectSourceGame source)
         {
             // clang-format off
-            return (IsFilterActive(FILTER_RCT1) && source == ObjectSourceGame::RCT1) ||
-                   (IsFilterActive(FILTER_AA)   && source == ObjectSourceGame::AddedAttractions) ||
-                   (IsFilterActive(FILTER_LL)   && source == ObjectSourceGame::LoopyLandscapes) ||
-                   (IsFilterActive(FILTER_RCT2) && source == ObjectSourceGame::RCT2) ||
-                   (IsFilterActive(FILTER_WW)   && source == ObjectSourceGame::WackyWorlds) ||
-                   (IsFilterActive(FILTER_TT)   && source == ObjectSourceGame::TimeTwister) ||
-                   (IsFilterActive(FILTER_OO)   && source == ObjectSourceGame::OpenRCT2Official) ||
+            return (IsFilterActive(FILTER_RCT1) && source == ObjectSourceGame::rct1) ||
+                   (IsFilterActive(FILTER_AA)   && source == ObjectSourceGame::addedAttractions) ||
+                   (IsFilterActive(FILTER_LL)   && source == ObjectSourceGame::loopyLandscapes) ||
+                   (IsFilterActive(FILTER_RCT2) && source == ObjectSourceGame::rct2) ||
+                   (IsFilterActive(FILTER_WW)   && source == ObjectSourceGame::wackyWorlds) ||
+                   (IsFilterActive(FILTER_TT)   && source == ObjectSourceGame::timeTwister) ||
+                   (IsFilterActive(FILTER_OO)   && source == ObjectSourceGame::openRCT2Official) ||
                    (IsFilterActive(FILTER_CUSTOM) &&
-                        source != ObjectSourceGame::RCT1 &&
-                        source != ObjectSourceGame::AddedAttractions &&
-                        source != ObjectSourceGame::LoopyLandscapes &&
-                        source != ObjectSourceGame::RCT2 &&
-                        source != ObjectSourceGame::WackyWorlds &&
-                        source != ObjectSourceGame::TimeTwister &&
-                        source != ObjectSourceGame::OpenRCT2Official);
+                        source != ObjectSourceGame::rct1 &&
+                        source != ObjectSourceGame::addedAttractions &&
+                        source != ObjectSourceGame::loopyLandscapes &&
+                        source != ObjectSourceGame::rct2 &&
+                        source != ObjectSourceGame::wackyWorlds &&
+                        source != ObjectSourceGame::timeTwister &&
+                        source != ObjectSourceGame::openRCT2Official);
             // clang-format on
         }
 
@@ -1562,7 +1568,7 @@ namespace OpenRCT2::Ui::Windows
 
         ObjectType GetSelectedObjectType()
         {
-            auto& currentPage = ObjectSelectionPages[selected_tab];
+            auto& currentPage = ObjectSelectionPages[selectedTab];
             auto& subTabs = currentPage.subTabs;
             if (!subTabs.empty())
                 return subTabs[_selectedSubTab].subObjectType;
@@ -1591,9 +1597,9 @@ namespace OpenRCT2::Ui::Windows
         {
             for (size_t i = 0; i < std::size(ObjectSelectionPages); i++)
             {
-                pressed_widgets &= ~(1ull << (WIDX_TAB_1 + i));
+                pressedWidgets &= ~(1ull << (WIDX_TAB_1 + i));
             }
-            pressed_widgets |= 1LL << (WIDX_TAB_1 + selected_tab);
+            pressedWidgets |= 1LL << (WIDX_TAB_1 + selectedTab);
         }
 
         /**
@@ -1614,7 +1620,7 @@ namespace OpenRCT2::Ui::Windows
             const auto* rideEntry = GetRideEntryByIndex(entry_index);
             auto rideType = rideEntry->GetFirstNonNullRideType();
 
-            auto intent = Intent(WindowClass::TrackDesignList);
+            auto intent = Intent(WindowClass::trackDesignList);
             intent.PutExtra(INTENT_EXTRA_RIDE_TYPE, rideType);
             intent.PutExtra(INTENT_EXTRA_RIDE_ENTRY_INDEX, entry_index);
             ContextOpenIntent(&intent);
@@ -1629,21 +1635,22 @@ namespace OpenRCT2::Ui::Windows
     {
         auto* windowMgr = GetWindowManager();
         return windowMgr->FocusOrCreate<EditorObjectSelectionWindow>(
-            WindowClass::EditorObjectSelection, kWindowSize, WF_10 | WF_RESIZABLE | WF_CENTRE_SCREEN);
+            WindowClass::editorObjectSelection, kWindowSize,
+            { WindowFlag::higherContrastOnPress, WindowFlag::resizable, WindowFlag::centreScreen });
     }
 
     // Used for forced closure
     void EditorObjectSelectionClose()
     {
         auto* windowMgr = GetWindowManager();
-        auto window = windowMgr->FindByClass(WindowClass::EditorObjectSelection);
+        auto window = windowMgr->FindByClass(WindowClass::editorObjectSelection);
         if (window == nullptr)
         {
             return;
         }
         auto objSelWindow = static_cast<EditorObjectSelectionWindow*>(window);
         objSelWindow->SetOverrideChecks(true);
-        objSelWindow->Close();
+        objSelWindow->close();
     }
 
     static bool VisibleListSortRideName(const ObjectListItem& a, const ObjectListItem& b)
@@ -1744,7 +1751,7 @@ namespace OpenRCT2::Ui::Windows
         ContextShowError(STR_INVALID_SELECTION_OF_OBJECTS, errorString, {});
 
         auto* windowMgr = Ui::GetWindowManager();
-        WindowBase* w = windowMgr->FindByClass(WindowClass::EditorObjectSelection);
+        WindowBase* w = windowMgr->FindByClass(WindowClass::editorObjectSelection);
         if (w != nullptr)
         {
             // Click tab with missing object
