@@ -20,6 +20,7 @@
 #include <openrct2/core/File.h>
 #include <openrct2/core/Path.hpp>
 #include <openrct2/core/UnitConversion.h>
+#include <openrct2/drawing/Rectangle.h>
 #include <openrct2/localisation/Formatter.h>
 #include <openrct2/object/ObjectManager.h>
 #include <openrct2/ride/RideConstruction.h>
@@ -30,6 +31,8 @@
 #include <string>
 #include <vector>
 
+using namespace OpenRCT2::Drawing;
+
 namespace OpenRCT2::Ui::Windows
 {
     enum
@@ -44,21 +47,20 @@ namespace OpenRCT2::Ui::Windows
         WIDX_CANCEL
     };
 
-    static constexpr StringId WINDOW_TITLE = STR_TRACK_DESIGN_INSTALL_WINDOW_TITLE;
-    static constexpr int32_t WW = 380;
-    static constexpr int32_t WH = 460;
-    constexpr int32_t PREVIEW_BUTTONS_LEFT = WW - 25;
-    constexpr int32_t ACTION_BUTTONS_LEFT = WW - 100;
+    static constexpr StringId kWindowTitle = STR_TRACK_DESIGN_INSTALL_WINDOW_TITLE;
+    static constexpr ScreenSize kWindowSize = { 380, 460 };
+    constexpr int32_t kPreviewButtonsLeft = kWindowSize.width - 25;
+    constexpr int32_t kActionButtonsLeft = kWindowSize.width - 100;
 
     // clang-format off
-    static constexpr Widget window_install_track_widgets[] = {
-        WINDOW_SHIM(WINDOW_TITLE, WW, WH),
-        MakeWidget({                   4,  18}, {372, 219}, WindowWidgetType::FlatBtn, WindowColour::Primary                                                              ),
-        MakeWidget({PREVIEW_BUTTONS_LEFT, 422}, { 22,  24}, WindowWidgetType::FlatBtn, WindowColour::Primary, ImageId(SPR_ROTATE_ARROW),                     STR_ROTATE_90_TIP     ),
-        MakeWidget({PREVIEW_BUTTONS_LEFT, 398}, { 22,  24}, WindowWidgetType::FlatBtn, WindowColour::Primary, ImageId(SPR_SCENERY),                          STR_TOGGLE_SCENERY_TIP),
-        MakeWidget({ ACTION_BUTTONS_LEFT, 241}, { 97,  15}, WindowWidgetType::Button,  WindowColour::Primary, STR_INSTALL_NEW_TRACK_DESIGN_INSTALL                        ),
-        MakeWidget({ ACTION_BUTTONS_LEFT, 259}, { 97,  15}, WindowWidgetType::Button,  WindowColour::Primary, STR_INSTALL_NEW_TRACK_DESIGN_CANCEL                         ),
-    };
+    static constexpr auto window_install_track_widgets = makeWidgets(
+        makeWindowShim(kWindowTitle, kWindowSize),
+        makeWidget({                  4,  18}, {372, 219}, WidgetType::flatBtn, WindowColour::primary                                                              ),
+        makeWidget({kPreviewButtonsLeft, 422}, { 22,  24}, WidgetType::flatBtn, WindowColour::primary, ImageId(SPR_ROTATE_ARROW),            STR_ROTATE_90_TIP     ),
+        makeWidget({kPreviewButtonsLeft, 398}, { 22,  24}, WidgetType::flatBtn, WindowColour::primary, ImageId(SPR_SCENERY),                 STR_TOGGLE_SCENERY_TIP),
+        makeWidget({ kActionButtonsLeft, 241}, { 97,  15}, WidgetType::button,  WindowColour::primary, STR_INSTALL_NEW_TRACK_DESIGN_INSTALL                        ),
+        makeWidget({ kActionButtonsLeft, 259}, { 97,  15}, WidgetType::button,  WindowColour::primary, STR_INSTALL_NEW_TRACK_DESIGN_CANCEL                         )
+    );
     // clang-format on
 
     class InstallTrackWindow final : public Window
@@ -70,7 +72,7 @@ namespace OpenRCT2::Ui::Windows
         std::vector<uint8_t> _trackDesignPreviewPixels;
 
     public:
-        void SetupTrack(const utf8* path, std::unique_ptr<TrackDesign> trackDesign)
+        void setupTrack(const utf8* path, std::unique_ptr<TrackDesign> trackDesign)
         {
             _trackDesign = std::move(trackDesign);
             _trackPath = path;
@@ -78,18 +80,18 @@ namespace OpenRCT2::Ui::Windows
             _trackDesignPreviewPixels.resize(4 * kTrackPreviewImageSize);
 
             UpdatePreview();
-            Invalidate();
+            invalidate();
         }
 
-        void OnOpen() override
+        void onOpen() override
         {
-            SetWidgets(window_install_track_widgets);
+            setWidgets(window_install_track_widgets);
 
             WindowInitScrollWidgets(*this);
             WindowPushOthersRight(*this);
         }
 
-        void OnClose() override
+        void onClose() override
         {
             _trackPath.clear();
             _trackName.clear();
@@ -98,23 +100,23 @@ namespace OpenRCT2::Ui::Windows
             _trackDesign = nullptr;
         }
 
-        void OnMouseUp(WidgetIndex widgetIndex) override
+        void onMouseUp(WidgetIndex widgetIndex) override
         {
             switch (widgetIndex)
             {
                 case WIDX_CLOSE:
                 case WIDX_CANCEL:
-                    Close();
+                    close();
                     break;
                 case WIDX_ROTATE:
                     _currentTrackPieceDirection++;
                     _currentTrackPieceDirection %= 4;
-                    Invalidate();
+                    invalidate();
                     break;
                 case WIDX_TOGGLE_SCENERY:
                     gTrackDesignSceneryToggle = !gTrackDesignSceneryToggle;
                     UpdatePreview();
-                    Invalidate();
+                    invalidate();
                     break;
                 case WIDX_INSTALL:
                     InstallTrackDesign();
@@ -122,7 +124,7 @@ namespace OpenRCT2::Ui::Windows
             }
         }
 
-        void OnTextInput(WidgetIndex widgetIndex, std::string_view text) override
+        void onTextInput(WidgetIndex widgetIndex, std::string_view text) override
         {
             if (widgetIndex != WIDX_INSTALL || text.empty())
             {
@@ -131,31 +133,31 @@ namespace OpenRCT2::Ui::Windows
 
             _trackName = std::string(text);
 
-            OnMouseUp(WIDX_INSTALL);
+            onMouseUp(WIDX_INSTALL);
         }
 
-        void OnPrepareDraw() override
+        void onPrepareDraw() override
         {
-            pressed_widgets |= 1uLL << WIDX_TRACK_PREVIEW;
+            pressedWidgets |= 1uLL << WIDX_TRACK_PREVIEW;
             if (!gTrackDesignSceneryToggle)
             {
-                pressed_widgets |= (1uLL << WIDX_TOGGLE_SCENERY);
+                pressedWidgets |= (1uLL << WIDX_TOGGLE_SCENERY);
             }
             else
             {
-                pressed_widgets &= ~(1uLL << WIDX_TOGGLE_SCENERY);
+                pressedWidgets &= ~(1uLL << WIDX_TOGGLE_SCENERY);
             }
         }
 
-        void OnDraw(DrawPixelInfo& dpi) override
+        void onDraw(RenderTarget& rt) override
         {
-            DrawWidgets(dpi);
+            drawWidgets(rt);
 
             // Track preview
             Widget* widget = &widgets[WIDX_TRACK_PREVIEW];
             auto screenPos = windowPos + ScreenCoordsXY{ widget->left + 1, widget->top + 1 };
             int32_t colour = ColourMapA[colours[0].colour].darkest;
-            GfxFillRect(dpi, { screenPos, screenPos + ScreenCoordsXY{ 369, 216 } }, colour);
+            Rectangle::fill(rt, { screenPos, screenPos + ScreenCoordsXY{ 369, 216 } }, colour);
 
             G1Element g1temp = {};
             g1temp.offset = _trackDesignPreviewPixels.data() + (_currentTrackPieceDirection * kTrackPreviewImageSize);
@@ -164,7 +166,7 @@ namespace OpenRCT2::Ui::Windows
             g1temp.flags = G1_FLAG_HAS_TRANSPARENCY;
             GfxSetG1Element(SPR_TEMP, &g1temp);
             DrawingEngineInvalidateImage(SPR_TEMP);
-            GfxDrawSprite(dpi, ImageId(SPR_TEMP), screenPos);
+            GfxDrawSprite(rt, ImageId(SPR_TEMP), screenPos);
 
             screenPos = windowPos + ScreenCoordsXY{ widget->midX(), widget->bottom - 12 };
 
@@ -176,7 +178,7 @@ namespace OpenRCT2::Ui::Windows
                 {
                     // Scenery not available
                     DrawTextEllipsised(
-                        dpi, screenPos, 308, STR_DESIGN_INCLUDES_SCENERY_WHICH_IS_UNAVAILABLE, {}, { TextAlignment::CENTRE });
+                        rt, screenPos, 308, STR_DESIGN_INCLUDES_SCENERY_WHICH_IS_UNAVAILABLE, {}, { TextAlignment::CENTRE });
                     screenPos.y -= kListRowHeight;
                 }
             }
@@ -190,7 +192,7 @@ namespace OpenRCT2::Ui::Windows
                 auto trackName = _trackName.c_str();
                 auto ft = Formatter();
                 ft.Add<const char*>(trackName);
-                DrawTextBasic(dpi, screenPos - ScreenCoordsXY{ 1, 0 }, STR_TRACK_DESIGN_NAME, ft);
+                DrawTextBasic(rt, screenPos - ScreenCoordsXY{ 1, 0 }, STR_TRACK_DESIGN_NAME, ft);
                 screenPos.y += kListRowHeight;
             }
 
@@ -202,7 +204,7 @@ namespace OpenRCT2::Ui::Windows
                 if (objectEntry != nullptr)
                 {
                     auto groupIndex = ObjectManagerGetLoadedObjectEntryIndex(objectEntry);
-                    auto rideName = GetRideNaming(td.trackAndVehicle.rtdIndex, *GetRideEntryByIndex(groupIndex));
+                    auto rideName = GetRideNaming(td.trackAndVehicle.rtdIndex, GetRideEntryByIndex(groupIndex));
                     ft.Add<StringId>(rideName.Name);
                 }
                 else
@@ -211,7 +213,7 @@ namespace OpenRCT2::Ui::Windows
                     ft.Add<StringId>(GetRideTypeDescriptor(td.trackAndVehicle.rtdIndex).Naming.Name);
                 }
 
-                DrawTextBasic(dpi, screenPos, STR_TRACK_DESIGN_TYPE, ft);
+                DrawTextBasic(rt, screenPos, STR_TRACK_DESIGN_TYPE, ft);
                 screenPos.y += kListRowHeight + 4;
             }
 
@@ -220,21 +222,21 @@ namespace OpenRCT2::Ui::Windows
                 fixed32_2dp rating = td.statistics.ratings.excitement;
                 auto ft = Formatter();
                 ft.Add<int32_t>(rating);
-                DrawTextBasic(dpi, screenPos, STR_TRACK_LIST_EXCITEMENT_RATING, ft);
+                DrawTextBasic(rt, screenPos, STR_TRACK_LIST_EXCITEMENT_RATING, ft);
                 screenPos.y += kListRowHeight;
             }
             {
                 fixed32_2dp rating = td.statistics.ratings.intensity;
                 auto ft = Formatter();
                 ft.Add<int32_t>(rating);
-                DrawTextBasic(dpi, screenPos, STR_TRACK_LIST_INTENSITY_RATING, ft);
+                DrawTextBasic(rt, screenPos, STR_TRACK_LIST_INTENSITY_RATING, ft);
                 screenPos.y += kListRowHeight;
             }
             {
                 fixed32_2dp rating = td.statistics.ratings.nausea;
                 auto ft = Formatter();
                 ft.Add<int32_t>(rating);
-                DrawTextBasic(dpi, screenPos, STR_TRACK_LIST_NAUSEA_RATING, ft);
+                DrawTextBasic(rt, screenPos, STR_TRACK_LIST_NAUSEA_RATING, ft);
                 screenPos.y += kListRowHeight + 4;
             }
 
@@ -246,7 +248,7 @@ namespace OpenRCT2::Ui::Windows
                     // Holes
                     auto ft = Formatter();
                     ft.Add<uint16_t>(td.statistics.holes);
-                    DrawTextBasic(dpi, screenPos, STR_HOLES, ft);
+                    DrawTextBasic(rt, screenPos, STR_HOLES, ft);
                     screenPos.y += kListRowHeight;
                 }
                 else
@@ -256,7 +258,7 @@ namespace OpenRCT2::Ui::Windows
                         uint16_t speed = ToHumanReadableSpeed(td.statistics.maxSpeed << 16);
                         auto ft = Formatter();
                         ft.Add<uint16_t>(speed);
-                        DrawTextBasic(dpi, screenPos, STR_MAX_SPEED, ft);
+                        DrawTextBasic(rt, screenPos, STR_MAX_SPEED, ft);
                         screenPos.y += kListRowHeight;
                     }
                     // Average speed
@@ -264,7 +266,7 @@ namespace OpenRCT2::Ui::Windows
                         uint16_t speed = ToHumanReadableSpeed(td.statistics.averageSpeed << 16);
                         auto ft = Formatter();
                         ft.Add<uint16_t>(speed);
-                        DrawTextBasic(dpi, screenPos, STR_AVERAGE_SPEED, ft);
+                        DrawTextBasic(rt, screenPos, STR_AVERAGE_SPEED, ft);
                         screenPos.y += kListRowHeight;
                     }
                 }
@@ -273,7 +275,7 @@ namespace OpenRCT2::Ui::Windows
                 auto ft = Formatter();
                 ft.Add<StringId>(STR_RIDE_LENGTH_ENTRY);
                 ft.Add<uint16_t>(td.statistics.rideLength);
-                DrawTextEllipsised(dpi, screenPos, 214, STR_TRACK_LIST_RIDE_LENGTH, ft);
+                DrawTextEllipsised(rt, screenPos, 214, STR_TRACK_LIST_RIDE_LENGTH, ft);
                 screenPos.y += kListRowHeight;
             }
 
@@ -284,7 +286,7 @@ namespace OpenRCT2::Ui::Windows
                     int32_t gForces = td.statistics.maxPositiveVerticalG;
                     auto ft = Formatter();
                     ft.Add<int32_t>(gForces);
-                    DrawTextBasic(dpi, screenPos, STR_MAX_POSITIVE_VERTICAL_G, ft);
+                    DrawTextBasic(rt, screenPos, STR_MAX_POSITIVE_VERTICAL_G, ft);
                     screenPos.y += kListRowHeight;
                 }
                 // Maximum negative vertical Gs
@@ -292,7 +294,7 @@ namespace OpenRCT2::Ui::Windows
                     int32_t gForces = td.statistics.maxNegativeVerticalG;
                     auto ft = Formatter();
                     ft.Add<int32_t>(gForces);
-                    DrawTextBasic(dpi, screenPos, STR_MAX_NEGATIVE_VERTICAL_G, ft);
+                    DrawTextBasic(rt, screenPos, STR_MAX_NEGATIVE_VERTICAL_G, ft);
                     screenPos.y += kListRowHeight;
                 }
                 // Maximum lateral Gs
@@ -300,7 +302,7 @@ namespace OpenRCT2::Ui::Windows
                     int32_t gForces = td.statistics.maxLateralG;
                     auto ft = Formatter();
                     ft.Add<int32_t>(gForces);
-                    DrawTextBasic(dpi, screenPos, STR_MAX_LATERAL_G, ft);
+                    DrawTextBasic(rt, screenPos, STR_MAX_LATERAL_G, ft);
                     screenPos.y += kListRowHeight;
                 }
                 if (td.statistics.totalAirTime != 0)
@@ -308,7 +310,7 @@ namespace OpenRCT2::Ui::Windows
                     int32_t airTime = ToHumanReadableAirTime(td.statistics.totalAirTime);
                     auto ft = Formatter();
                     ft.Add<int32_t>(airTime);
-                    DrawTextBasic(dpi, screenPos, STR_TOTAL_AIR_TIME, ft);
+                    DrawTextBasic(rt, screenPos, STR_TOTAL_AIR_TIME, ft);
                     screenPos.y += kListRowHeight;
                 }
             }
@@ -317,11 +319,11 @@ namespace OpenRCT2::Ui::Windows
             {
                 auto ft = Formatter();
                 ft.Add<uint16_t>(td.statistics.drops);
-                DrawTextBasic(dpi, screenPos, STR_DROPS, ft);
+                DrawTextBasic(rt, screenPos, STR_DROPS, ft);
                 screenPos.y += kListRowHeight;
 
                 // Drop height is multiplied by 0.75
-                DrawTextBasic(dpi, screenPos, STR_HIGHEST_DROP_HEIGHT, ft);
+                DrawTextBasic(rt, screenPos, STR_HIGHEST_DROP_HEIGHT, ft);
                 screenPos.y += kListRowHeight;
             }
 
@@ -330,7 +332,7 @@ namespace OpenRCT2::Ui::Windows
                 // Inversions
                 auto ft = Formatter();
                 ft.Add<uint16_t>(td.statistics.inversions);
-                DrawTextBasic(dpi, screenPos, STR_INVERSIONS, ft);
+                DrawTextBasic(rt, screenPos, STR_INVERSIONS, ft);
                 screenPos.y += kListRowHeight;
             }
 
@@ -342,7 +344,7 @@ namespace OpenRCT2::Ui::Windows
                 auto ft = Formatter();
                 ft.Add<uint16_t>(td.statistics.spaceRequired.x);
                 ft.Add<uint16_t>(td.statistics.spaceRequired.y);
-                DrawTextBasic(dpi, screenPos, STR_TRACK_LIST_SPACE_REQUIRED, ft);
+                DrawTextBasic(rt, screenPos, STR_TRACK_LIST_SPACE_REQUIRED, ft);
                 screenPos.y += kListRowHeight;
             }
 
@@ -350,25 +352,20 @@ namespace OpenRCT2::Ui::Windows
             {
                 auto ft = Formatter();
                 ft.Add<money64>(td.gameStateData.cost);
-                DrawTextBasic(dpi, screenPos, STR_TRACK_LIST_COST_AROUND, ft);
+                DrawTextBasic(rt, screenPos, STR_TRACK_LIST_COST_AROUND, ft);
             }
         }
 
-        void OnResize() override
-        {
-            ResizeFrame();
-        }
-
     private:
         void UpdatePreview()
         {
-            TrackDesignDrawPreview(*_trackDesign, _trackDesignPreviewPixels.data());
+            TrackDesignDrawPreview(*_trackDesign, _trackDesignPreviewPixels.data(), !gTrackDesignSceneryToggle);
         }
 
         void InstallTrackDesign()
         {
-            auto env = OpenRCT2::GetContext()->GetPlatformEnvironment();
-            auto destPath = env->GetDirectoryPath(OpenRCT2::DIRBASE::USER, OpenRCT2::DIRID::TRACK);
+            auto& env = OpenRCT2::GetContext()->GetPlatformEnvironment();
+            auto destPath = env.GetDirectoryPath(OpenRCT2::DirBase::user, OpenRCT2::DirId::trackDesigns);
             if (!Path::CreateDirectory(destPath))
             {
                 LOG_ERROR("Unable to create directory '%s'", destPath.c_str());
@@ -390,7 +387,7 @@ namespace OpenRCT2::Ui::Windows
             {
                 if (TrackRepositoryInstall(_trackPath.c_str(), _trackName.c_str()))
                 {
-                    Close();
+                    close();
                 }
                 else
                 {
@@ -422,18 +419,15 @@ namespace OpenRCT2::Ui::Windows
         }
 
         auto* windowMgr = Ui::GetWindowManager();
-        windowMgr->CloseByClass(WindowClass::EditorObjectSelection);
+        windowMgr->ForceClose(WindowClass::editorObjectSelection);
         windowMgr->CloseConstructionWindows();
 
         gTrackDesignSceneryToggle = false;
         _currentTrackPieceDirection = 2;
 
-        int32_t screenWidth = ContextGetWidth();
-        int32_t screenHeight = ContextGetHeight();
-        auto screenPos = ScreenCoordsXY{ screenWidth / 2 - 201, std::max(kTopToolbarHeight + 1, screenHeight / 2 - 200) };
-
-        auto* window = windowMgr->FocusOrCreate<InstallTrackWindow>(WindowClass::InstallTrack, screenPos, WW, WH, 0);
-        window->SetupTrack(path, std::move(trackDesign));
+        auto* window = windowMgr->FocusOrCreate<InstallTrackWindow>(
+            WindowClass::installTrack, kWindowSize, { WindowFlag::autoPosition, WindowFlag::centreScreen });
+        window->setupTrack(path, std::move(trackDesign));
 
         return window;
     }
