@@ -19,6 +19,7 @@
 #include <openrct2/core/String.hpp>
 #include <openrct2/core/UnitConversion.h>
 #include <openrct2/drawing/IDrawingEngine.h>
+#include <openrct2/drawing/Rectangle.h>
 #include <openrct2/localisation/Formatting.h>
 #include <openrct2/ride/RideConstruction.h>
 #include <openrct2/ride/RideData.h>
@@ -28,6 +29,8 @@
 #include <openrct2/windows/Intent.h>
 #include <vector>
 
+using namespace OpenRCT2::Drawing;
+
 namespace OpenRCT2::Ui::Windows
 {
     static constexpr StringId kWindowTitle = STR_SELECT_DESIGN;
@@ -50,7 +53,7 @@ namespace OpenRCT2::Ui::Windows
         WIDX_TOGGLE_SCENERY,
     };
 
-    validate_global_widx(WC_TRACK_DESIGN_LIST, WIDX_ROTATE);
+    VALIDATE_GLOBAL_WIDX(WC_TRACK_DESIGN_LIST, WIDX_ROTATE);
 
     // clang-format off
     static constexpr auto kFlatBtnSize = ScreenSize{kRotateAndSceneryButtonSize, kRotateAndSceneryButtonSize};
@@ -109,20 +112,20 @@ namespace OpenRCT2::Ui::Windows
             }
 
             // Ensure that the selected item is still in the list.
-            if (static_cast<size_t>(selected_list_item) >= _filteredTrackIds.size())
+            if (static_cast<size_t>(selectedListItem) >= _filteredTrackIds.size())
             {
-                selected_list_item = 0;
+                selectedListItem = 0;
             }
         }
 
         void SelectFromList(int32_t listIndex)
         {
-            OpenRCT2::Audio::Play(OpenRCT2::Audio::SoundId::Click1, 0, this->windowPos.x + (this->width / 2));
+            OpenRCT2::Audio::Play(OpenRCT2::Audio::SoundId::click1, 0, this->windowPos.x + (this->width / 2));
             if (!(gLegacyScene == LegacyScene::trackDesignsManager))
             {
                 if (listIndex == 0)
                 {
-                    Close();
+                    close();
                     RideConstructNew(_window_track_list_item);
                     return;
                 }
@@ -145,7 +148,7 @@ namespace OpenRCT2::Ui::Windows
             TrackDesignFileRef* tdRef = &_trackDesigns[trackDesignIndex];
             if (gLegacyScene == LegacyScene::trackDesignsManager)
             {
-                auto intent = Intent(WindowClass::ManageTrackDesign);
+                auto intent = Intent(WindowClass::manageTrackDesign);
                 intent.PutExtra(INTENT_EXTRA_TRACK_DESIGN, tdRef);
                 ContextOpenIntent(&intent);
             }
@@ -157,7 +160,7 @@ namespace OpenRCT2::Ui::Windows
                     ContextShowError(STR_THIS_DESIGN_WILL_BE_BUILT_WITH_AN_ALTERNATIVE_VEHICLE_TYPE, kStringIdNone, {});
                 }
 
-                auto intent = Intent(WindowClass::TrackDesignPlace);
+                auto intent = Intent(WindowClass::trackDesignPlace);
                 intent.PutExtra(INTENT_EXTRA_TRACK_DESIGN, tdRef);
                 ContextOpenIntent(&intent);
             }
@@ -201,7 +204,7 @@ namespace OpenRCT2::Ui::Windows
             _loadedTrackDesign = TrackDesignImport(path.c_str());
             if (_loadedTrackDesign != nullptr)
             {
-                TrackDesignDrawPreview(*_loadedTrackDesign, _trackDesignPreviewPixels.data());
+                TrackDesignDrawPreview(*_loadedTrackDesign, _trackDesignPreviewPixels.data(), !gTrackDesignSceneryToggle);
                 return true;
             }
             return false;
@@ -213,10 +216,10 @@ namespace OpenRCT2::Ui::Windows
             _window_track_list_item = item;
         }
 
-        void OnOpen() override
+        void onOpen() override
         {
             String::set(_filterString, sizeof(_filterString), "");
-            SetWidgets(_trackListWidgets);
+            setWidgets(_trackListWidgets);
             widgets[WIDX_FILTER_STRING].string = _filterString;
 
             LoadDesignsList(_window_track_list_item);
@@ -225,10 +228,10 @@ namespace OpenRCT2::Ui::Windows
             _selectedItemIsBeingUpdated = false;
             _reloadTrackDesigns = false;
             // Start with first track highlighted
-            selected_list_item = 0;
+            selectedListItem = 0;
             if (_trackDesigns.size() != 0 && !(gLegacyScene == LegacyScene::trackDesignsManager))
             {
-                selected_list_item = 1;
+                selectedListItem = 1;
             }
             gTrackDesignSceneryToggle = false;
             WindowPushOthersRight(*this);
@@ -242,12 +245,12 @@ namespace OpenRCT2::Ui::Windows
         void ReopenTrackManager()
         {
             auto* windowMgr = Ui::GetWindowManager();
-            windowMgr->CloseByNumber(WindowClass::ManageTrackDesign, number);
-            windowMgr->CloseByNumber(WindowClass::TrackDeletePrompt, number);
+            windowMgr->CloseByNumber(WindowClass::manageTrackDesign, number);
+            windowMgr->CloseByNumber(WindowClass::trackDeletePrompt, number);
             Editor::LoadTrackManager();
         }
 
-        void OnClose() override
+        void onClose() override
         {
             // Dispose track design and preview
             _loadedTrackDesign = nullptr;
@@ -268,28 +271,28 @@ namespace OpenRCT2::Ui::Windows
             }
         }
 
-        void OnMouseUp(const WidgetIndex widgetIndex) override
+        void onMouseUp(const WidgetIndex widgetIndex) override
         {
             switch (widgetIndex)
             {
                 case WIDX_CLOSE:
-                    Close();
+                    close();
                     break;
                 case WIDX_ROTATE:
                     _currentTrackPieceDirection++;
                     _currentTrackPieceDirection %= 4;
-                    Invalidate();
+                    invalidate();
                     break;
                 case WIDX_TOGGLE_SCENERY:
                     gTrackDesignSceneryToggle = !gTrackDesignSceneryToggle;
                     _loadedTrackDesignIndex = kTrackDesignIndexUnloaded;
-                    Invalidate();
+                    invalidate();
                     break;
                 case WIDX_BACK:
-                    Close();
+                    close();
                     if (!(gLegacyScene == LegacyScene::trackDesignsManager))
                     {
-                        ContextOpenWindow(WindowClass::ConstructRide);
+                        ContextOpenWindow(WindowClass::constructRide);
                     }
                     else
                     {
@@ -303,25 +306,25 @@ namespace OpenRCT2::Ui::Windows
                     // Keep the highlighted item selected
                     if (gLegacyScene == LegacyScene::trackDesignsManager)
                     {
-                        if (selected_list_item != -1 && _filteredTrackIds.size() > static_cast<size_t>(selected_list_item))
-                            selected_list_item = _filteredTrackIds[selected_list_item];
+                        if (selectedListItem != -1 && _filteredTrackIds.size() > static_cast<size_t>(selectedListItem))
+                            selectedListItem = _filteredTrackIds[selectedListItem];
                         else
-                            selected_list_item = -1;
+                            selectedListItem = -1;
                     }
                     else
                     {
-                        if (selected_list_item != 0)
-                            selected_list_item = _filteredTrackIds[selected_list_item - 1] + 1;
+                        if (selectedListItem != 0)
+                            selectedListItem = _filteredTrackIds[selectedListItem - 1] + 1;
                     }
 
                     String::set(_filterString, sizeof(_filterString), "");
                     FilterList();
-                    Invalidate();
+                    invalidate();
                     break;
             }
         }
 
-        ScreenSize OnScrollGetSize(const int32_t scrollIndex) override
+        ScreenSize onScrollGetSize(const int32_t scrollIndex) override
         {
             size_t numItems = _filteredTrackIds.size();
             if (!(gLegacyScene == LegacyScene::trackDesignsManager))
@@ -334,7 +337,7 @@ namespace OpenRCT2::Ui::Windows
             return { width, scrollHeight };
         }
 
-        void OnScrollMouseDown(const int32_t scrollIndex, const ScreenCoordsXY& screenCoords) override
+        void onScrollMouseDown(const int32_t scrollIndex, const ScreenCoordsXY& screenCoords) override
         {
             if (!_selectedItemIsBeingUpdated)
             {
@@ -346,20 +349,20 @@ namespace OpenRCT2::Ui::Windows
             }
         }
 
-        void OnScrollMouseOver(const int32_t scrollIndex, const ScreenCoordsXY& screenCoords) override
+        void onScrollMouseOver(const int32_t scrollIndex, const ScreenCoordsXY& screenCoords) override
         {
             if (!_selectedItemIsBeingUpdated)
             {
                 int32_t i = GetListItemFromPosition(screenCoords);
-                if (i != -1 && selected_list_item != i)
+                if (i != -1 && selectedListItem != i)
                 {
-                    selected_list_item = i;
-                    Invalidate();
+                    selectedListItem = i;
+                    invalidate();
                 }
             }
         }
 
-        void OnTextInput(const WidgetIndex widgetIndex, std::string_view text) override
+        void onTextInput(const WidgetIndex widgetIndex, std::string_view text) override
         {
             if (widgetIndex != WIDX_FILTER_STRING)
                 return;
@@ -373,17 +376,17 @@ namespace OpenRCT2::Ui::Windows
 
             scrolls->contentOffsetY = 0;
 
-            Invalidate();
+            invalidate();
         }
 
-        void OnPrepareDraw() override
+        void onPrepareDraw() override
         {
             StringId stringId = kStringIdNone;
             const auto* entry = GetRideEntryByIndex(_window_track_list_item.EntryIndex);
 
             if (entry != nullptr)
             {
-                RideNaming rideName = GetRideNaming(_window_track_list_item.Type, *entry);
+                RideNaming rideName = GetRideNaming(_window_track_list_item.Type, entry);
                 stringId = rideName.Name;
             }
 
@@ -399,31 +402,31 @@ namespace OpenRCT2::Ui::Windows
                 widgets[WIDX_TRACK_LIST].tooltip = STR_CLICK_ON_DESIGN_TO_BUILD_IT_TIP;
             }
 
-            if ((gLegacyScene == LegacyScene::trackDesignsManager) || selected_list_item != 0)
+            if ((gLegacyScene == LegacyScene::trackDesignsManager) || selectedListItem != 0)
             {
-                pressed_widgets |= 1uLL << WIDX_TRACK_PREVIEW;
-                disabled_widgets &= ~(1uLL << WIDX_TRACK_PREVIEW);
+                pressedWidgets |= 1uLL << WIDX_TRACK_PREVIEW;
+                disabledWidgets &= ~(1uLL << WIDX_TRACK_PREVIEW);
                 widgets[WIDX_ROTATE].type = WidgetType::flatBtn;
                 widgets[WIDX_TOGGLE_SCENERY].type = WidgetType::flatBtn;
                 if (gTrackDesignSceneryToggle)
                 {
-                    pressed_widgets &= ~(1uLL << WIDX_TOGGLE_SCENERY);
+                    pressedWidgets &= ~(1uLL << WIDX_TOGGLE_SCENERY);
                 }
                 else
                 {
-                    pressed_widgets |= (1uLL << WIDX_TOGGLE_SCENERY);
+                    pressedWidgets |= (1uLL << WIDX_TOGGLE_SCENERY);
                 }
             }
             else
             {
-                pressed_widgets &= ~(1uLL << WIDX_TRACK_PREVIEW);
-                disabled_widgets |= (1uLL << WIDX_TRACK_PREVIEW);
+                pressedWidgets &= ~(1uLL << WIDX_TRACK_PREVIEW);
+                disabledWidgets |= (1uLL << WIDX_TRACK_PREVIEW);
                 widgets[WIDX_ROTATE].type = WidgetType::empty;
                 widgets[WIDX_TOGGLE_SCENERY].type = WidgetType::empty;
             }
 
             // When debugging tools are on, shift everything up a bit to make room for displaying the path.
-            const int32_t bottomMargin = Config::Get().general.DebuggingTools ? (kWindowPadding + kDebugPathHeight)
+            const int32_t bottomMargin = Config::Get().general.debuggingTools ? (kWindowPadding + kDebugPathHeight)
                                                                               : kWindowPadding;
             widgets[WIDX_TRACK_LIST].bottom = height - bottomMargin;
             widgets[WIDX_ROTATE].bottom = height - bottomMargin;
@@ -432,28 +435,28 @@ namespace OpenRCT2::Ui::Windows
             widgets[WIDX_TOGGLE_SCENERY].top = widgets[WIDX_TOGGLE_SCENERY].bottom - kRotateAndSceneryButtonSize;
         }
 
-        void OnUpdate() override
+        void onUpdate() override
         {
             if (GetCurrentTextBox().window.classification == classification && GetCurrentTextBox().window.number == number)
             {
                 WindowUpdateTextboxCaret();
-                InvalidateWidget(WIDX_FILTER_STRING); // TODO Check this
+                invalidateWidget(WIDX_FILTER_STRING); // TODO Check this
             }
 
             if (_reloadTrackDesigns)
             {
                 LoadDesignsList(_window_track_list_item);
-                selected_list_item = 0;
-                Invalidate();
+                selectedListItem = 0;
+                invalidate();
                 _reloadTrackDesigns = false;
             }
         }
 
-        void OnDraw(RenderTarget& rt) override
+        void onDraw(RenderTarget& rt) override
         {
-            DrawWidgets(rt);
+            drawWidgets(rt);
 
-            int32_t listItemIndex = selected_list_item;
+            int32_t listItemIndex = selectedListItem;
             if ((gLegacyScene == LegacyScene::trackDesignsManager) == 0)
             {
                 // Because the first item in the list is "Build a custom design", lower the index by one
@@ -471,7 +474,7 @@ namespace OpenRCT2::Ui::Windows
             u8string path = _trackDesigns[trackIndex].path;
 
             // Show track file path (in debug mode)
-            if (Config::Get().general.DebuggingTools)
+            if (Config::Get().general.debuggingTools)
             {
                 const auto shortPath = ShortenPath(path, width, FontStyle::Medium);
                 auto ft = Formatter();
@@ -482,7 +485,7 @@ namespace OpenRCT2::Ui::Windows
             }
 
             auto screenPos = windowPos + ScreenCoordsXY{ tdWidget.left + 1, tdWidget.top + 1 };
-            GfxFillRect(rt, { screenPos, screenPos + ScreenCoordsXY{ 369, 216 } }, colour); // TODO Check dpi
+            Rectangle::fill(rt, { screenPos, screenPos + ScreenCoordsXY{ 369, 216 } }, colour); // TODO Check dpi
 
             if (_loadedTrackDesignIndex != trackIndex)
             {
@@ -670,7 +673,7 @@ namespace OpenRCT2::Ui::Windows
             }
         }
 
-        void OnScrollDraw(const int32_t scrollIndex, RenderTarget& rt) override
+        void onScrollDraw(const int32_t scrollIndex, RenderTarget& rt) override
         {
             uint8_t paletteIndex = ColourMapA[colours[0].colour].mid_light;
             GfxClear(rt, paletteIndex);
@@ -690,12 +693,12 @@ namespace OpenRCT2::Ui::Windows
             {
                 // Build custom track item
                 StringId stringId;
-                if (listIndex == static_cast<size_t>(selected_list_item))
+                if (listIndex == static_cast<size_t>(selectedListItem))
                 {
                     // Highlight
-                    GfxFilterRect(
+                    Rectangle::filter(
                         rt, { screenCoords, { width, screenCoords.y + kScrollableRowHeight - 1 } },
-                        FilterPaletteID::PaletteDarken1);
+                        FilterPaletteID::paletteDarken1);
                     stringId = STR_WINDOW_COLOUR_2_STRINGID;
                 }
                 else
@@ -715,12 +718,12 @@ namespace OpenRCT2::Ui::Windows
                 if (screenCoords.y + kScrollableRowHeight >= rt.y && screenCoords.y < rt.y + rt.height)
                 {
                     StringId stringId;
-                    if (listIndex == static_cast<size_t>(selected_list_item))
+                    if (listIndex == static_cast<size_t>(selectedListItem))
                     {
                         // Highlight
-                        GfxFilterRect(
+                        Rectangle::filter(
                             rt, { screenCoords, { width, screenCoords.y + kScrollableRowHeight - 1 } },
-                            FilterPaletteID::PaletteDarken1);
+                            FilterPaletteID::paletteDarken1);
                         stringId = STR_WINDOW_COLOUR_2_STRINGID;
                     }
                     else
@@ -756,24 +759,24 @@ namespace OpenRCT2::Ui::Windows
         auto* windowMgr = Ui::GetWindowManager();
         windowMgr->CloseConstructionWindows();
 
-        WindowFlags flags = 0;
+        WindowFlags flags = {};
         ScreenCoordsXY screenPos{};
         if (gLegacyScene == LegacyScene::trackDesignsManager)
         {
-            flags = WF_AUTO_POSITION | WF_CENTRE_SCREEN;
+            flags = { WindowFlag::autoPosition, WindowFlag::centreScreen };
         }
         else
         {
             screenPos = { 0, kTopToolbarHeight + 2 };
         }
 
-        return windowMgr->Create<TrackListWindow>(WindowClass::TrackDesignList, screenPos, kWindowSize, flags, item);
+        return windowMgr->Create<TrackListWindow>(WindowClass::trackDesignList, screenPos, kWindowSize, flags, item);
     }
 
     void WindowTrackDesignListReloadTracks()
     {
         auto* windowMgr = GetWindowManager();
-        auto* trackListWindow = static_cast<TrackListWindow*>(windowMgr->FindByClass(WindowClass::TrackDesignList));
+        auto* trackListWindow = static_cast<TrackListWindow*>(windowMgr->FindByClass(WindowClass::trackDesignList));
         if (trackListWindow != nullptr)
         {
             trackListWindow->ReloadTrackDesigns();
@@ -783,7 +786,7 @@ namespace OpenRCT2::Ui::Windows
     void WindowTrackDesignListSetBeingUpdated(const bool beingUpdated)
     {
         auto* windowMgr = GetWindowManager();
-        auto* trackListWindow = static_cast<TrackListWindow*>(windowMgr->FindByClass(WindowClass::TrackDesignList));
+        auto* trackListWindow = static_cast<TrackListWindow*>(windowMgr->FindByClass(WindowClass::trackDesignList));
         if (trackListWindow != nullptr)
         {
             trackListWindow->SetIsBeingUpdated(beingUpdated);
