@@ -45,6 +45,8 @@
 #include "world/Climate.h"
 #include "world/Entrance.h"
 #include "world/Footpath.h"
+#include "world/Map.h"
+#include "world/MapLimits.h"
 #include "world/Park.h"
 #include "world/Scenery.h"
 
@@ -91,9 +93,9 @@ namespace OpenRCT2::Editor
 
     static WindowBase* OpenEditorWindows()
     {
-        auto* main = ContextOpenWindow(WindowClass::MainWindow);
-        ContextOpenWindow(WindowClass::TopToolbar);
-        ContextOpenWindowView(WV_EDITOR_BOTTOM_TOOLBAR);
+        auto* main = ContextOpenWindow(WindowClass::mainWindow);
+        ContextOpenWindow(WindowClass::topToolbar);
+        ContextOpenWindowView(WindowView::editorBottomToolbar);
         return main;
     }
 
@@ -117,7 +119,7 @@ namespace OpenRCT2::Editor
         ObjectListLoad();
         ViewportInitAll();
         WindowBase* mainWindow = OpenEditorWindows();
-        mainWindow->SetViewportLocation(TileCoordsXYZ{ 75, 75, 14 }.ToCoordsXYZ());
+        mainWindow->setViewportLocation(TileCoordsXYZ{ 75, 75, 14 }.ToCoordsXYZ());
         LoadPalette();
         gScreenAge = 0;
         gameState.scenarioOptions.name = LanguageGetString(STR_MY_NEW_SCENARIO);
@@ -133,7 +135,7 @@ namespace OpenRCT2::Editor
     void ConvertSaveToScenario()
     {
         ToolCancel();
-        auto intent = Intent(WindowClass::Loadsave);
+        auto intent = Intent(WindowClass::loadsave);
         intent.PutEnumExtra<LoadSaveAction>(INTENT_EXTRA_LOADSAVE_ACTION, LoadSaveAction::load);
         intent.PutEnumExtra<LoadSaveType>(INTENT_EXTRA_LOADSAVE_TYPE, LoadSaveType::park);
         intent.PutExtra(INTENT_EXTRA_CALLBACK, reinterpret_cast<CloseCallback>(ConvertSaveToScenarioCallback));
@@ -194,7 +196,7 @@ namespace OpenRCT2::Editor
         ObjectListLoad();
         ViewportInitAll();
         WindowBase* mainWindow = OpenEditorWindows();
-        mainWindow->SetViewportLocation(TileCoordsXYZ{ 75, 75, 14 }.ToCoordsXYZ());
+        mainWindow->setViewportLocation(TileCoordsXYZ{ 75, 75, 14 }.ToCoordsXYZ());
         LoadPalette();
 
         GameLoadScripts();
@@ -222,7 +224,7 @@ namespace OpenRCT2::Editor
         ObjectListLoad();
         ViewportInitAll();
         WindowBase* mainWindow = OpenEditorWindows();
-        mainWindow->SetViewportLocation(TileCoordsXYZ{ 75, 75, 14 }.ToCoordsXYZ());
+        mainWindow->setViewportLocation(TileCoordsXYZ{ 75, 75, 14 }.ToCoordsXYZ());
         LoadPalette();
 
         GameLoadScripts();
@@ -236,16 +238,17 @@ namespace OpenRCT2::Editor
     static void SetAllLandOwned()
     {
         auto& gameState = getGameState();
+
         MapRange range = { 2 * kCoordsXYStep, 2 * kCoordsXYStep, (gameState.mapSize.x - 3) * kCoordsXYStep,
                            (gameState.mapSize.y - 3) * kCoordsXYStep };
 
         auto landSetRightsAction = GameActions::LandSetRightsAction(range, GameActions::LandSetRightSetting::SetForSale);
         landSetRightsAction.SetFlags(GAME_COMMAND_FLAG_NO_SPEND);
-        GameActions::Execute(&landSetRightsAction);
+        GameActions::Execute(&landSetRightsAction, gameState);
 
         auto landBuyRightsAction = GameActions::LandBuyRightsAction(range, GameActions::LandBuyRightSetting::BuyLand);
         landBuyRightsAction.SetFlags(GAME_COMMAND_FLAG_NO_SPEND);
-        GameActions::Execute(&landBuyRightsAction);
+        GameActions::Execute(&landBuyRightsAction, gameState);
     }
 
     static void AfterLoadCleanup(bool loadedFromSave)
@@ -300,7 +303,7 @@ namespace OpenRCT2::Editor
             staff->SetName({});
         }
 
-        ResetAllEntities();
+        getGameState().entities.ResetAllEntities();
         UpdateConsolidatedPatrolAreas();
 
         auto& gameState = getGameState();
@@ -357,12 +360,12 @@ namespace OpenRCT2::Editor
         switch (getGameState().editorStep)
         {
             case EditorStep::ObjectSelection:
-                if (windowMgr->FindByClass(WindowClass::EditorObjectSelection) != nullptr)
+                if (windowMgr->FindByClass(WindowClass::editorObjectSelection) != nullptr)
                 {
                     return;
                 }
 
-                if (windowMgr->FindByClass(WindowClass::InstallTrack) != nullptr)
+                if (windowMgr->FindByClass(WindowClass::installTrack) != nullptr)
                 {
                     return;
                 }
@@ -372,25 +375,25 @@ namespace OpenRCT2::Editor
                     ObjectManagerUnloadAllObjects();
                 }
 
-                ContextOpenWindow(WindowClass::EditorObjectSelection);
+                ContextOpenWindow(WindowClass::editorObjectSelection);
                 break;
             case EditorStep::InventionsListSetUp:
-                if (windowMgr->FindByClass(WindowClass::EditorInventionList) != nullptr)
+                if (windowMgr->FindByClass(WindowClass::editorInventionList) != nullptr)
                 {
                     return;
                 }
 
-                ContextOpenWindow(WindowClass::EditorInventionList);
+                ContextOpenWindow(WindowClass::editorInventionList);
                 break;
             case EditorStep::OptionsSelection:
             case EditorStep::ObjectiveSelection:
             case EditorStep::ScenarioDetails:
-                if (windowMgr->FindByClass(WindowClass::EditorScenarioOptions) != nullptr)
+                if (windowMgr->FindByClass(WindowClass::editorScenarioOptions) != nullptr)
                 {
                     return;
                 }
 
-                ContextOpenWindow(WindowClass::EditorScenarioOptions);
+                ContextOpenWindow(WindowClass::editorScenarioOptions);
                 break;
             case EditorStep::LandscapeEditor:
             case EditorStep::SaveScenario:
@@ -471,11 +474,11 @@ namespace OpenRCT2::Editor
 
         using OpenRCT2::AnimationPeepType;
         constexpr std::pair<AnimationPeepType, StringId> kPeepCheckPairs[] = {
-            { AnimationPeepType::Guest, STR_AT_LEAST_ONE_GUEST_PEEP_ANIMATIONS_OBJECT_MUST_BE_SELECTED },
-            { AnimationPeepType::Handyman, STR_AT_LEAST_ONE_HANDYMAN_PEEP_ANIMATIONS_OBJECT_MUST_BE_SELECTED },
-            { AnimationPeepType::Mechanic, STR_AT_LEAST_ONE_MECHANIC_PEEP_ANIMATIONS_OBJECT_MUST_BE_SELECTED },
-            { AnimationPeepType::Security, STR_AT_LEAST_ONE_SECURITY_PEEP_ANIMATIONS_OBJECT_MUST_BE_SELECTED },
-            { AnimationPeepType::Entertainer, STR_AT_LEAST_ONE_ENTERTAINER_PEEP_ANIMATIONS_OBJECT_MUST_BE_SELECTED },
+            { AnimationPeepType::guest, STR_AT_LEAST_ONE_GUEST_PEEP_ANIMATIONS_OBJECT_MUST_BE_SELECTED },
+            { AnimationPeepType::handyman, STR_AT_LEAST_ONE_HANDYMAN_PEEP_ANIMATIONS_OBJECT_MUST_BE_SELECTED },
+            { AnimationPeepType::mechanic, STR_AT_LEAST_ONE_MECHANIC_PEEP_ANIMATIONS_OBJECT_MUST_BE_SELECTED },
+            { AnimationPeepType::security, STR_AT_LEAST_ONE_SECURITY_PEEP_ANIMATIONS_OBJECT_MUST_BE_SELECTED },
+            { AnimationPeepType::entertainer, STR_AT_LEAST_ONE_ENTERTAINER_PEEP_ANIMATIONS_OBJECT_MUST_BE_SELECTED },
         };
 
         for (auto& pair : kPeepCheckPairs)
@@ -496,7 +499,8 @@ namespace OpenRCT2::Editor
     ResultWithMessage CheckPark()
     {
         auto& gameState = getGameState();
-        int32_t parkSize = Park::UpdateSize(gameState);
+        auto& park = gameState.park;
+        int32_t parkSize = Park::UpdateSize(park);
         if (parkSize == 0)
         {
             return { false, STR_PARK_MUST_OWN_SOME_LAND };
