@@ -23,6 +23,7 @@
 #include "../world/ConstructionClearance.h"
 #include "../world/Footpath.h"
 #include "../world/Location.hpp"
+#include "../world/Map.h"
 #include "../world/Park.h"
 #include "../world/QuarterTile.h"
 #include "../world/Scenery.h"
@@ -38,7 +39,7 @@
 namespace OpenRCT2::GameActions
 {
     FootpathPlaceAction::FootpathPlaceAction(
-        const CoordsXYZ& loc, uint8_t slope, ObjectEntryIndex type, ObjectEntryIndex railingsType, Direction direction,
+        const CoordsXYZ& loc, FootpathSlope slope, ObjectEntryIndex type, ObjectEntryIndex railingsType, Direction direction,
         PathConstructFlags constructFlags)
         : _loc(loc)
         , _slope(slope)
@@ -55,7 +56,8 @@ namespace OpenRCT2::GameActions
         visitor.Visit("object", _type);
         visitor.Visit("railingsObject", _railingsType);
         visitor.Visit("direction", _direction);
-        visitor.Visit("slope", _slope);
+        visitor.Visit("slopeType", _slope.type);
+        visitor.Visit("slopeDirection", _slope.direction);
         visitor.Visit("constructFlags", _constructFlags);
     }
 
@@ -72,7 +74,7 @@ namespace OpenRCT2::GameActions
                << DS_TAG(_constructFlags);
     }
 
-    Result FootpathPlaceAction::Query() const
+    Result FootpathPlaceAction::Query(GameState_t& gameState) const
     {
         auto res = Result();
         res.Cost = 0;
@@ -91,7 +93,7 @@ namespace OpenRCT2::GameActions
             return Result(Status::Disallowed, STR_CANT_BUILD_FOOTPATH_HERE, STR_LAND_NOT_OWNED_BY_PARK);
         }
 
-        if (_slope & SLOPE_IS_IRREGULAR_FLAG)
+        if (_slope.type == FootpathSlopeType::irregular || _slope.type == FootpathSlopeType::raise)
         {
             return Result(Status::Disallowed, STR_CANT_BUILD_FOOTPATH_HERE, STR_LAND_SLOPE_UNSUITABLE);
         }
@@ -115,7 +117,7 @@ namespace OpenRCT2::GameActions
         auto intent = Intent(INTENT_ACTION_REMOVE_PROVISIONAL_FOOTPATH);
         ContextBroadcastIntent(&intent);
 
-        auto tileElement = MapGetFootpathElementSlope(_loc, _slope);
+        auto tileElement = MapGetFootpathElementWithSlope(_loc, _slope);
         if (tileElement == nullptr)
         {
             return ElementInsertQuery(std::move(res));
@@ -123,7 +125,7 @@ namespace OpenRCT2::GameActions
         return ElementUpdateQuery(tileElement, std::move(res));
     }
 
-    Result FootpathPlaceAction::Execute() const
+    Result FootpathPlaceAction::Execute(GameState_t& gameState) const
     {
         auto res = Result();
         res.Cost = 0;
@@ -148,14 +150,15 @@ namespace OpenRCT2::GameActions
                 auto zLow = _loc.z;
                 auto zHigh = zLow + kPathClearance;
                 WallRemoveIntersectingWalls(
-                    { _loc, zLow, zHigh + ((_slope & kTileSlopeRaisedCornersMask) ? 16 : 0) }, DirectionReverse(_direction));
+                    { _loc, zLow, zHigh + ((_slope.type == FootpathSlopeType::sloped) ? 16 : 0) },
+                    DirectionReverse(_direction));
                 WallRemoveIntersectingWalls(
                     { _loc.x - CoordsDirectionDelta[_direction].x, _loc.y - CoordsDirectionDelta[_direction].y, zLow, zHigh },
                     _direction);
             }
         }
 
-        auto tileElement = MapGetFootpathElementSlope(_loc, _slope);
+        auto tileElement = MapGetFootpathElementWithSlope(_loc, _slope);
         if (tileElement == nullptr)
         {
             return ElementInsertExecute(std::move(res));
@@ -222,7 +225,7 @@ namespace OpenRCT2::GameActions
 
         if (GetFlags() & GAME_COMMAND_FLAG_GHOST && !pathElement->IsGhost())
         {
-            return Result(Status::Unknown, STR_CANT_BUILD_FOOTPATH_HERE, kStringIdNone);
+            return Result(Status::ItemAlreadyPlaced, STR_CANT_BUILD_FOOTPATH_HERE, kStringIdNone);
         }
         return res;
     }
@@ -294,9 +297,9 @@ namespace OpenRCT2::GameActions
         QuarterTile quarterTile{ 0b1111, 0 };
         auto zLow = _loc.z;
         auto zHigh = zLow + kPathClearance;
-        if (_slope & FOOTPATH_PROPERTIES_FLAG_IS_SLOPED)
+        if (_slope.type == FootpathSlopeType::sloped)
         {
-            quarterTile = QuarterTile{ 0b1111, 0b1100 }.Rotate(_slope & kTileElementDirectionMask);
+            quarterTile = QuarterTile{ 0b1111, 0b1100 }.Rotate(_slope.direction);
             zHigh += kPathHeightStep;
         }
 
@@ -314,10 +317,10 @@ namespace OpenRCT2::GameActions
 
         // Do not attempt to build a crossing with a queue or a sloped path.
         auto isQueue = _constructFlags & PathConstructFlag::IsQueue;
-        auto crossingMode = isQueue || (_slope != kTileSlopeFlat) ? CreateCrossingMode::none
-                                                                  : CreateCrossingMode::pathOverTrack;
+        auto crossingMode = isQueue || (_slope.type != FootpathSlopeType::flat) ? CreateCrossingMode::none
+                                                                                : CreateCrossingMode::pathOverTrack;
         auto canBuild = MapCanConstructWithClearAt(
-            { _loc, zLow, zHigh }, &MapPlaceNonSceneryClearFunc, quarterTile, GetFlags(), crossingMode);
+            { _loc, zLow, zHigh }, &MapPlaceNonSceneryClearFunc, quarterTile, GetFlags(), kTileSlopeFlat, crossingMode);
         if (!entrancePath && canBuild.Error != Status::Ok)
         {
             canBuild.ErrorTitle = STR_CANT_BUILD_FOOTPATH_HERE;
@@ -362,9 +365,9 @@ namespace OpenRCT2::GameActions
         QuarterTile quarterTile{ 0b1111, 0 };
         auto zLow = _loc.z;
         auto zHigh = zLow + kPathClearance;
-        if (_slope & FOOTPATH_PROPERTIES_FLAG_IS_SLOPED)
+        if (_slope.type == FootpathSlopeType::sloped)
         {
-            quarterTile = QuarterTile{ 0b1111, 0b1100 }.Rotate(_slope & kTileElementDirectionMask);
+            quarterTile = QuarterTile{ 0b1111, 0b1100 }.Rotate(_slope.direction);
             zHigh += kPathHeightStep;
         }
 
@@ -382,11 +385,11 @@ namespace OpenRCT2::GameActions
 
         // Do not attempt to build a crossing with a queue or a sloped.
         auto isQueue = _constructFlags & PathConstructFlag::IsQueue;
-        auto crossingMode = isQueue || (_slope != kTileSlopeFlat) ? CreateCrossingMode::none
-                                                                  : CreateCrossingMode::pathOverTrack;
+        auto crossingMode = isQueue || (_slope.type != FootpathSlopeType::flat) ? CreateCrossingMode::none
+                                                                                : CreateCrossingMode::pathOverTrack;
         auto canBuild = MapCanConstructWithClearAt(
             { _loc, zLow, zHigh }, &MapPlaceNonSceneryClearFunc, quarterTile, GAME_COMMAND_FLAG_APPLY | GetFlags(),
-            crossingMode);
+            kTileSlopeFlat, crossingMode);
         if (!entrancePath && canBuild.Error != Status::Ok)
         {
             canBuild.ErrorTitle = STR_CANT_BUILD_FOOTPATH_HERE;
@@ -435,8 +438,8 @@ namespace OpenRCT2::GameActions
                 pathElement->SetSurfaceEntryIndex(_type);
                 pathElement->SetRailingsEntryIndex(_railingsType);
             }
-            pathElement->SetSlopeDirection(_slope & FOOTPATH_PROPERTIES_SLOPE_DIRECTION_MASK);
-            pathElement->SetSloped(_slope & FOOTPATH_PROPERTIES_FLAG_IS_SLOPED);
+            pathElement->SetSlopeDirection(_slope.direction);
+            pathElement->SetSloped(_slope.type == FootpathSlopeType::sloped);
             pathElement->SetIsQueue(isQueue);
             pathElement->SetAddition(0);
             pathElement->SetRideIndex(RideId::GetNull());
@@ -524,10 +527,9 @@ namespace OpenRCT2::GameActions
         MapInvalidateTileFull(_loc);
     }
 
-    PathElement* FootpathPlaceAction::MapGetFootpathElementSlope(const CoordsXYZ& footpathPos, int32_t slope) const
+    PathElement* FootpathPlaceAction::MapGetFootpathElementWithSlope(const CoordsXYZ& footpathPos, FootpathSlope slope) const
     {
-        const bool isSloped = slope & FOOTPATH_PROPERTIES_FLAG_IS_SLOPED;
-        const auto slopeDirection = slope & FOOTPATH_PROPERTIES_SLOPE_DIRECTION_MASK;
+        const bool isSloped = slope.type == FootpathSlopeType::sloped;
 
         for (auto* pathElement : TileElementsView<PathElement>(footpathPos))
         {
@@ -535,7 +537,7 @@ namespace OpenRCT2::GameActions
                 continue;
             if (pathElement->IsSloped() != isSloped)
                 continue;
-            if (pathElement->GetSlopeDirection() != slopeDirection)
+            if (pathElement->GetSlopeDirection() != slope.direction)
                 continue;
             return pathElement;
         }
