@@ -11,7 +11,7 @@
 
 #include "../Identifiers.h"
 #include "../object/Object.h"
-#include "../world/Map.h"
+#include "../world/Location.hpp"
 #include "../world/QuarterTile.h"
 
 #include <optional>
@@ -26,10 +26,12 @@ constexpr uint8_t kMaximumTrackSpeed = 30;
 namespace OpenRCT2
 {
     enum class TrackElemType : uint16_t;
-}
+
+    struct TileElement;
+    struct TrackElement;
+} // namespace OpenRCT2
 
 struct ResultWithMessage;
-struct TileElement;
 
 enum class TrackRoll : uint8_t
 {
@@ -152,6 +154,10 @@ enum class TrackGroup : uint8_t
     diagSlopeSteepLong,
     diveLoop,
 
+    diagSlope,
+    diagSlopeSteepUp,
+    diagSlopeSteepDown,
+
     count,
 };
 
@@ -648,7 +654,7 @@ struct TrackCircuitIterator
     CoordsXYE current;
     int32_t currentZ;
     int32_t currentDirection;
-    TileElement* first;
+    OpenRCT2::TileElement* first;
     bool firstIteration;
     bool looped;
 };
@@ -708,7 +714,7 @@ struct TypeOrCurve
 PitchAndRoll TrackPitchAndRollStart(OpenRCT2::TrackElemType trackType);
 PitchAndRoll TrackPitchAndRollEnd(OpenRCT2::TrackElemType trackType);
 
-int32_t TrackIsConnectedByShape(TileElement* a, TileElement* b);
+int32_t TrackIsConnectedByShape(OpenRCT2::TileElement* a, OpenRCT2::TileElement* b);
 
 void TrackCircuitIteratorBegin(TrackCircuitIterator* it, CoordsXYE first);
 bool TrackCircuitIteratorPrevious(TrackCircuitIterator* it);
@@ -718,7 +724,7 @@ bool TrackCircuitIteratorsMatch(const TrackCircuitIterator* firstIt, const Track
 void TrackGetBack(const CoordsXYE& input, CoordsXYE* output);
 void TrackGetFront(const CoordsXYE& input, CoordsXYE* output);
 
-TrackElement* TrackGetPreviousBlock(CoordsXYZ& location, TileElement* tileElement);
+OpenRCT2::TrackElement* TrackGetPreviousBlock(CoordsXYZ& location, OpenRCT2::TileElement* tileElement);
 
 bool TrackElementIsCovered(OpenRCT2::TrackElemType trackElementType);
 OpenRCT2::TrackElemType UncoverTrackElement(OpenRCT2::TrackElemType trackElementType);
@@ -727,13 +733,9 @@ bool TrackTypeIsBrakes(OpenRCT2::TrackElemType trackType);
 bool TrackTypeIsBlockBrakes(OpenRCT2::TrackElemType trackType);
 bool TrackTypeIsBooster(OpenRCT2::TrackElemType trackType);
 
-std::optional<CoordsXYZ> GetTrackElementOriginAndApplyChanges(
-    const CoordsXYZD& location, OpenRCT2::TrackElemType type, uint16_t extra_params, TileElement** output_element,
-    uint16_t flags);
-
-TrackRoll TrackGetActualBank(TileElement* tileElement, TrackRoll bank);
+TrackRoll TrackGetActualBank(OpenRCT2::TileElement* tileElement, TrackRoll bank);
 TrackRoll TrackGetActualBank2(ride_type_t rideType, bool isInverted, TrackRoll bank);
-TrackRoll TrackGetActualBank3(bool useInvertedSprites, TileElement* tileElement);
+TrackRoll TrackGetActualBank3(bool useInvertedSprites, OpenRCT2::TileElement* tileElement);
 
 ResultWithMessage TrackAddStationElement(CoordsXYZD loc, RideId rideIndex, int32_t flags, bool fromTrackDesign);
 ResultWithMessage TrackRemoveStationElement(const CoordsXYZD& loc, RideId rideIndex, int32_t flags);
